#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from os.path import dirname, realpath
from PyQt5 import QtCore, QtWidgets, QtGui
from collections import OrderedDict
from matplotlib.cm import get_cmap
import csv

from eccw_gui.plot_app.viewers.plot_main import Ui_Form
from eccw_gui.plot_app.controllers.curve_settings import CurveController
from eccw_gui.plot_app.controllers.point_settings import RefPointSettings
from eccw_gui.plot_app.controllers.title_settings import TitleEdit
from eccw_gui.plot_app.controllers.dialog_errors import Errors
from eccw_gui.plot_app.controllers.plot_window import PlotWindow
from eccw_gui.shared.wrappers import Wrapper, WrapperDict, WrapperList
from eccw_gui.shared.tools import graph_print

from eccw import EccwPlot


class PlotController(QtWidgets.QWidget, Ui_Form, WrapperDict):
    """Main widget for plotting curve and points.

    Keyword arguments:
    curves    -- awaits a dict of keyword arguments for a CurveController
                 element.
    refpoints -- awaits a dict of keyword arguments for a RefPointSettings
                 element.
    legend    -- awaits a boolean.
    title     -- awaits a boolean.

    This is a Qt derived object.
    """

    def __init__(self, **kwargs):
        super(PlotController, self).__init__()
        self.setupUi(self)
        self.plot_core = EccwPlot()
        self.plot_window = PlotWindow(self.plot_core.figure)
        self.current_dir = QtCore.QDir.homePath()
        self.import_mimetypes = (
            "Fichiers texte (*.txt *.dat *.csv);;" "Tout les Fichiers (*.*)"
        )
        # Init local attributs.
        self.curve_count = 0
        self.curves = WrapperList()
        self.refpoints = WrapperList()
        self.legend = Wrapper(
            False,
            process=lambda x: eval(str(x)),
            action=self.checkBox_legend.setChecked,
        )
        self.range_point = Wrapper(
            False,
            process=lambda x: eval(str(x)),
            action=self.checkBox_pointRange.setChecked,
        )
        self.title = TitleEdit()
        self.horizontalLayout_title.addWidget(self.title)
        # Init events
        self.pushButton_addRefPoint.clicked.connect(self.add_ref_point)
        self.pushButton_killAllRefPoints.clicked.connect(self.kill_all_refpoints)
        self.pushButton_openRefPoints.clicked.connect(self.import_ref_points)
        self.pushButton_addCurve.clicked.connect(self.add_curve_tab)
        self.pushButton_killAllCurves.clicked.connect(self.kill_all_curves)
        self.checkBox_legend.clicked.connect(self._set_legend)
        self.checkBox_pointRange.clicked.connect(self._set_range_point)
        # self.radioButton_title.clicked.connect(self._set_title)
        self.pushButton_plotOne.clicked.connect(self.plot_one)
        self.pushButton_plotAll.clicked.connect(self.plot_all)
        self.tabWidget.tabBar().tabMoved.connect(self._tab_moved)
        # Shortcuts
        TabW = self.tabWidget
        QtWidgets.QShortcut(
            QtGui.QKeySequence("Alt+Page up"),
            self,
            lambda: TabW.setCurrentIndex(TabW.currentIndex() - 1),
        )
        QtWidgets.QShortcut(
            QtGui.QKeySequence("Alt+Page down"),
            self,
            lambda: TabW.setCurrentIndex(TabW.currentIndex() + 1),
        )
        QtWidgets.QShortcut(
            QtGui.QKeySequence("Alt+T"), self, self.title.lineEdit.setFocus,
        )
        # Parameters list for dry and fluids cases.
        self.params_list_dry = ("phiB", "phiD")
        self.params_list_fluids = (
            "phiB",
            "phiD",
            "delta_lambdaB",
            "delta_lambdaD",
            "rho_f",
            "rho_sr",
        )
        self.params_list_refpoints = ("alpha", "beta")
        # Dictionnary (WrapperDict)
        self.dict = OrderedDict(
            [
                ("curves", self.curves),
                ("refpoints", self.refpoints),
                ("legend", self.legend),
                ("range_point", self.range_point),
                ("title", self.title),
            ]
        )
        # Additional variables
        self.latex_convert = {
            "alpha": r"$\alpha$",
            "beta": r"$\beta$",
            "phiB": r"$\phi_{B}$",
            "phiD": r"$\phi_{D}$",
            "delta_lambdaB": r"$\Delta \lambda_{B}$",
            "delta_lambdaD": r"$\Delta \lambda_{D}$",
            "rho_f": r"\rho_{f}$",
            "rho_sr": r"\rho_{sr}$",
        }
        self.html_convert = {
            "alpha": "α",
            "beta": "β",
            "phiB": "Φ<sub>B</sub>",
            "phiD": "Φ<sub>D</sub>",
            "delta_lambdaB": "∆λ<sub>B</sub>",
            "delta_lambdaD": "∆λ<sub>D</sub>",
            "rho_f": "ρ<sub>f</sub>",
            "rho_sr": "ρ<sub>sr</sub>",
        }
        # Fill values with kwargs
        if kwargs:
            self.set_params(**kwargs)
        if self.curve_count == 0:
            self.add_curve_tab()
        self.show()

    def closeEvent(self, event):
        """Close plot window when closing plot_main."""
        self.plot_window.close()
        event.accept()

    def set_params(self, **kwargs):
        # There must be as many curves and refpoints as asked to set.
        self.kill_all_curves()
        self.kill_all_refpoints()
        N = len(kwargs["curves"])
        for i in range(N):
            self.add_curve_tab(label=kwargs["curves"][i]["label"])
        N = len(kwargs["refpoints"])
        for i in range(N):
            self.add_ref_point()
        WrapperDict.set_params(self, **kwargs)

    def _set_legend(self):
        self.legend.value = self.checkBox_legend.isChecked()

    def _set_range_point(self):
        self.range_point.value = self.checkBox_pointRange.isChecked()

    def _tab_moved(self):
        self.curves.list = [
            self.tabWidget.widget(i) for i in range(self.tabWidget.count())
        ]

    def import_ref_points(self):
        """Add ref points using data from csv file.

        Awaited format:
        beta, alpha, size, style, label, red, green, blue, alpha_chanel

        beta in deg
        alpha in deg
        size in pixels
        style among ['c', 's', 'd', 't', '*', '+', 'p']
        label is any string value
        rgba color channels red, green , blue and alpha are floats in [0:1]
        """
        OpenDialog = QtWidgets.QFileDialog.getOpenFileName
        out_opendialog = OpenDialog(
            self, "Import from csv file", self.current_dir, self.import_mimetypes
        )
        file_name = out_opendialog[0]
        if file_name == "":
            return None  # Squip if no file selected.
        self.current_dir = dirname(realpath(file_name))
        with open(file_name, "r") as csvfile:
            parsed_data = csv.reader(csvfile)  # , dialect)
            errors = [
                "datas from file<br>%s<br> gets wrong items at lines:"
                "<br>" % file_name
            ]
            for i, row in enumerate(parsed_data):
                row = [elt.strip() for elt in row]
                if len(row) < 2:
                    errors.append("%s, " % (i + 1))
                    continue
                self.add_ref_point()
                params = {}
                params["beta"] = row[0]
                params["alpha"] = row[1]
                params["size"] = row[2] or 3.0 if len(row) > 2 else 3.0
                params["style"] = row[3] or "c" if len(row) > 3 else "circle"
                params["label"] = row[4] if len(row) > 4 else ""
                params["color"] = row[5:9] if len(row) > 8 else (0, 0, 0, 1)
                try:
                    self.refpoints.list[-1].set_params(**params)
                except TypeError:
                    errors.append("%s, " % (i + 1))
            if len(errors) > 1:
                errors.append(
                    "<br><br><b>Awaited parameters:</b><br>"
                    "beta, alpha, [size, style, label, color]<br>"
                    "<br><b>Awaited format:</b>"
                    "<table>"
                    "<tr><td>beta</th><td>float</th></tr>"
                    "<tr><td>alpha      </td><td>float</td></tr>"
                    "<tr><td>size</td><td>float &gt; 0</td></tr>"
                    "<tr><td>style</td><td>caracter in [c s d t * +"
                    " p]</td></tr>"
                    "<tr><td>label</td><td>string</td></tr>"
                    "<tr><td>color</td><td>4 floats in [0:1]</td>"
                    "</tr></table>"
                )
                QtWidgets.QMessageBox.about(self, "Warning", "".join(errors))

    # Curve tab management.

    def add_curve_tab(self, label=None):
        self.curve_count += 1
        name = "Curve " + str(self.curve_count) if label in (None, False) else label
        newCurve = CurveController(label=name)
        self.curves.list.append(newCurve)
        ncurve = len(self.curves.list)
        newCurve.pushButton_kill.clicked.connect(self.kill_curve_tab)
        # Single curve : put in frame widget
        if ncurve == 1:
            self.set_single_curve(newCurve)
            self.pushButton_killAllCurves.setEnabled(True)
        # Second curve : switch to tab widget
        elif ncurve == 2:
            firstCurve = self.curves.list[0]
            firstname = firstCurve.label.get_params()
            firstCurve.label.lineEdit.textChanged.connect(self._edit_tab_title)
            self.tabWidget.setVisible(True)
            self.tabWidget.addTab(firstCurve, firstname)
            self.frame_singleCurve.setVisible(False)
            firstCurve.setVisible(False)
        if ncurve > 1:
            self.tabWidget.addTab(newCurve, name)
            self.tabWidget.setCurrentWidget(newCurve)
            newCurve.label.lineEdit.textChanged.connect(self._edit_tab_title)

    def set_single_curve(self, curve):
        self.tabWidget.removeTab(0)
        self.tabWidget.setVisible(False)
        self.verticalLayout_singleCurve.addWidget(curve)
        curve.setVisible(True)
        self.frame_singleCurve.setVisible(True)

    def kill_curve_tab(self):
        for elt in list(self.curves.list):
            if elt.closed:
                i = self.tabWidget.indexOf(elt)
                self.tabWidget.setCurrentIndex(i - 1)
                self.tabWidget.removeTab(i)
                del self.curves.list[self.curves.list.index(elt)]
                break
        if len(self.curves.list) == 1:
            singlecurve = self.curves.list[0]
            self.set_single_curve(singlecurve)
            singlecurve.label.lineEdit.textChanged.disconnect(self._edit_tab_title)
        elif len(self.curves.list) == 0:
            self.pushButton_killAllCurves.setEnabled(False)

    def kill_all_curves(self):
        if len(self.curves.list) == 1:
            self.curves.list[0].close()
            self.curves.list[0].closed = True
            self.kill_curve_tab()
        else:
            for elt in list(self.curves.list):
                i = self.tabWidget.indexOf(elt)
                self.tabWidget.removeTab(i)
                del self.curves.list[self.curves.list.index(elt)]
        self.frame_singleCurve.setVisible(True)
        self.tabWidget.setVisible(False)
        self.pushButton_killAllCurves.setEnabled(False)

    def _edit_tab_title(self):
        i = self.tabWidget.currentIndex()
        title = self.tabWidget.currentWidget().label.get_params()
        self.tabWidget.setTabText(i, title)

    # RefPoint management.

    def add_ref_point(self):
        if not self.refpoints.list:
            self.pushButton_killAllRefPoints.setEnabled(True)
        newRefPoint = RefPointSettings()
        newRefPoint.pushButton_kill.clicked.connect(self.remove_ref_point)
        self.verticalLayout_points_settings.addWidget(newRefPoint)
        self.refpoints.list.append(newRefPoint)

    def remove_ref_point(self):
        for elt in list(self.refpoints.list):
            if elt.closed:
                del self.refpoints.list[self.refpoints.list.index(elt)]
        if not self.refpoints.list:
            self.pushButton_killAllRefPoints.setEnabled(False)

    def kill_all_refpoints(self):
        for elt in list(self.refpoints.list):
            elt.close()
            elt.closed = True
        self.remove_ref_point()
        self.pushButton_killAllRefPoints.setEnabled(False)

    # Main action !

    def plot_all(self):
        if len(self.curves.list) > 0:
            self.plot_core.reset_figure()
            selected_params = self.get_select()
            errors = self._check_params(selected_params)
            if not errors:
                for curve in selected_params["curves"]:
                    out = self._plot_curve(curve)
                    if out is not None:
                        self.plot_core.figure.clear()
                        self.errors = Errors(out)
                        return
                self._plot_other_stuffs(selected_params)
                self.plot_window.update()
                self.plot_window.show()
            else:
                self.errors = Errors(errors)

    def plot_one(self):
        if len(self.curves.list) > 0:
            self.plot_core.reset_figure()
            selected_params = self.get_select()
            i = self.tabWidget.currentIndex()
            curve = selected_params["curves"][i]
            errors = self._check_params(selected_params, index=i)
            if not errors:
                out = self._plot_curve(curve)
                if out is not None:
                    self.plot_core.figure.clear()
                    self.errors = Errors(out)
                    return
                self._plot_other_stuffs(selected_params)
                self.plot_window.update()
                self.plot_window.show()
            else:
                self.errors = Errors(errors)

    def _check_params(self, selected_params, index=None):
        errors = ""
        message = " gets empty or invalid value<br/>"
        iterable = [index] if index is not None else range(len(self.curves.list))
        for i in iterable:
            error = ""
            curve = selected_params["curves"][i]
            if curve["fluids"]:
                params_list = self.params_list_fluids
            else:
                params_list = self.params_list_dry
            for p_name in params_list:
                if curve[p_name]["value"] is None:
                    error += self.html_convert[p_name] + message
            if error:
                errors += "<b>" + curve["label"] + "</b><br/>" + error
        for i, refpoints in enumerate(selected_params["refpoints"]):
            error = ""
            for p_name in self.params_list_refpoints:
                if refpoints[p_name] is None:
                    error += self.html_convert[p_name] + message
            if error:
                label = refpoints["label"] or i + 1
                errors += "<b>Reference points %s</b><br/>" % (label) + error
        return errors

    def _plot_other_stuffs(self, selected_params, index=None):
        for refpoint in selected_params["refpoints"]:
            self.plot_core.add_refpoint(**refpoint)
        if selected_params["legend"]:
            self.plot_core.add_legend()
        if selected_params["title"]:
            self.plot_core.add_title(selected_params["title"])

    def _format_point_params(self, point_params, no_label=False):
        if point_params["beta"]["type"] == "scalar":
            params = {
                **point_params,
                "beta": point_params["beta"]["value"],
                "alpha": None,
                "alpha_min": point_params["alpha"]["value"]["min"],
                "alpha_max": point_params["alpha"]["value"]["max"],
            }
        if point_params["alpha"]["type"] == "scalar":
            params = {
                **point_params,
                "beta": None,
                "beta_min": point_params["beta"]["value"]["min"],
                "beta_max": point_params["beta"]["value"]["max"],
                "alpha": point_params["alpha"]["value"],
            }
        if no_label:
            params.pop("label")
        return params

    def _plot_curve(self, selected_params):
        settings_type = selected_params["settings"]["type"]
        if settings_type in ("default", "double"):
            out = self._plot_single_curve(selected_params)
        elif settings_type == "range":
            out = self._plot_ranged_curves(selected_params)
        return out

    def _plot_single_curve(self, selected_params):
        if selected_params["fluids"]:
            params_list = self.params_list_fluids
        else:
            params_list = self.params_list_dry
            self.plot_core.set_no_fluids()
        params = {
            "context": selected_params["context"],
            **{param: selected_params[param]["value"] for param in params_list},
        }
        graphic_settings = {
            "label": selected_params["label"],
            **selected_params["settings"]["value"],
        }
        self.plot_core.reset()
        self.plot_core.set_params(**params)
        # TEST
        errors = self.plot_core.check_params()
        if errors:
            return errors
        # END TEST
        self.plot_core.add_curve(**graphic_settings)
        # try:
        #     self.plot_core.set_params(**params)
        #     self.plot_core.add_curve(**graphic_settings)
        # except ValueError:
        #     self.errors = Errors("")
        #     return False
        # Draw points on line
        # and vertical or horizontal lines that visualize point intervals.
        for point in selected_params["points"]:
            params = self._format_point_params(point)
            self.plot_core.add_point(**params)
            if self.range_point.value is True:
                self.plot_core.add_line(**params)

    def _plot_ranged_curves(self, selected_params):
        if selected_params["fluids"]:
            params_list = self.params_list_fluids
        else:
            params_list = self.params_list_dry
            self.plot_core.set_no_fluids()
        graphic_settings = selected_params["settings"]["value"]
        ranged_parameter = selected_params["range"]
        latex_ranged_parameter = self.latex_convert[ranged_parameter]
        range_ = selected_params[ranged_parameter]["value"]
        if selected_params["reverse_cmap"]:
            cmap = get_cmap(graphic_settings.pop("colormap") + "_r")
        else:
            cmap = get_cmap(graphic_settings.pop("colormap"))
        number_of_color = len(range_) - 1
        # Ghost element that will be used as a title in the legend.
        self.plot_core.add_point(style="", label=selected_params["label"])
        # Draw ranged curves.
        for i, x in enumerate(range_):
            params = {
                "context": selected_params["context"],
                **{
                    param: selected_params[param]["value"]
                    if param != ranged_parameter
                    else x
                    for param in params_list
                },
            }
            self.plot_core.set_params(**params)
            # graphic_settings['color'] = cmap(i/number_of_color)
            graphic_settings.update(
                {
                    "label": (
                        latex_ranged_parameter + " = " + str(x)
                        if selected_params["label"]
                        else ""
                    ),
                    "color": cmap(i / number_of_color),
                }
            )
            self.plot_core.add_curve(**graphic_settings)
            for point in selected_params["points"]:
                params = self._format_point_params(point, no_label=True)
                try:  # DEBUG
                    self.plot_core.add_point(**params)
                except RuntimeError:
                    pass
        for point in selected_params["points"]:
            params = self._format_point_params(point)
            # Dummy element that will be used as legend for points to avoid
            # repetition.
            try:  # DEBUG
                self.plot_core.add_point(**params)
            except RuntimeError:
                pass
            # Draw vertical or horizontal lines that visualize point intervals
            if self.range_point.value is True:
                self.plot_core.add_line(**params)


if __name__ == "__main__":
    import sys
    from eccw_gui.shared.file_management import EccwFile

    eccwf = EccwFile(filename="../../../tests/data/test.eccw")
    # eccwf.show()
    params = eccwf.values["plot"]

    try:
        app = QtWidgets.QApplication(sys.argv)
        myapp = PlotController(**params)
        myapp.current_dir = "/home/bmary/Programmation/eccw/tests/"
        sys.exit(app.exec_())
    finally:
        print("params =")
        # graph_print(myapp.get_params())
        graph_print(myapp.get_select())



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../uis/plot_main.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(1032, 420)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(Form)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        spacerItem = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_title = QtWidgets.QHBoxLayout()
        self.horizontalLayout_title.setObjectName("horizontalLayout_title")
        self.verticalLayout.addLayout(self.horizontalLayout_title)
        spacerItem1 = QtWidgets.QSpacerItem(20, 27, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout.addItem(spacerItem1)
        self.horizontalLayout_enveloppes = QtWidgets.QHBoxLayout()
        self.horizontalLayout_enveloppes.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.horizontalLayout_enveloppes.setObjectName("horizontalLayout_enveloppes")
        self.pushButton_addCurve = QtWidgets.QPushButton(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_addCurve.sizePolicy().hasHeightForWidth())
        self.pushButton_addCurve.setSizePolicy(sizePolicy)
        self.pushButton_addCurve.setMinimumSize(QtCore.QSize(28, 28))
        self.pushButton_addCurve.setMaximumSize(QtCore.QSize(28, 28))
        self.pushButton_addCurve.setBaseSize(QtCore.QSize(28, 28))
        self.pushButton_addCurve.setObjectName("pushButton_addCurve")
        self.horizontalLayout_enveloppes.addWidget(self.pushButton_addCurve)
        self.label_enveloppes = QtWidgets.QLabel(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_enveloppes.sizePolicy().hasHeightForWidth())
        self.label_enveloppes.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_enveloppes.setFont(font)
        self.label_enveloppes.setObjectName("label_enveloppes")
        self.horizontalLayout_enveloppes.addWidget(self.label_enveloppes)
        self.line_2 = QtWidgets.QFrame(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.line_2.sizePolicy().hasHeightForWidth())
        self.line_2.setSizePolicy(sizePolicy)
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.horizontalLayout_enveloppes.addWidget(self.line_2)
        self.pushButton_killAllCurves = QtWidgets.QPushButton(Form)
        self.pushButton_killAllCurves.setEnabled(True)
        self.pushButton_killAllCurves.setMinimumSize(QtCore.QSize(70, 28))
        self.pushButton_killAllCurves.setMaximumSize(QtCore.QSize(70, 28))
        self.pushButton_killAllCurves.setBaseSize(QtCore.QSize(70, 28))
        self.pushButton_killAllCurves.setObjectName("pushButton_killAllCurves")
        self.horizontalLayout_enveloppes.addWidget(self.pushButton_killAllCurves)
        self.verticalLayout.addLayout(self.horizontalLayout_enveloppes)
        self.tabWidget = QtWidgets.QTabWidget(Form)
        self.tabWidget.setMinimumSize(QtCore.QSize(960, 0))
        self.tabWidget.setAutoFillBackground(True)
        self.tabWidget.setMovable(True)
        self.tabWidget.setObjectName("tabWidget")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.tab)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.tabWidget.addTab(self.tab, "")
        self.verticalLayout.addWidget(self.tabWidget)
        self.frame_singleCurve = QtWidgets.QFrame(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_singleCurve.sizePolicy().hasHeightForWidth())
        self.frame_singleCurve.setSizePolicy(sizePolicy)
        self.frame_singleCurve.setMinimumSize(QtCore.QSize(960, 0))
        self.frame_singleCurve.setBaseSize(QtCore.QSize(0, 10))
        self.frame_singleCurve.setFrameShape(QtWidgets.QFrame.Box)
        self.frame_singleCurve.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.frame_singleCurve.setObjectName("frame_singleCurve")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.frame_singleCurve)
        self.verticalLayout_3.setContentsMargins(1, 1, 1, 1)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.verticalLayout_singleCurve = QtWidgets.QVBoxLayout()
        self.verticalLayout_singleCurve.setObjectName("verticalLayout_singleCurve")
        self.verticalLayout_3.addLayout(self.verticalLayout_singleCurve)
        self.verticalLayout.addWidget(self.frame_singleCurve)
        spacerItem2 = QtWidgets.QSpacerItem(20, 27, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout.addItem(spacerItem2)
        self.horizontalLayout_refPoints = QtWidgets.QHBoxLayout()
        self.horizontalLayout_refPoints.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.horizontalLayout_refPoints.setObjectName("horizontalLayout_refPoints")
        self.pushButton_addRefPoint = QtWidgets.QPushButton(Form)
        self.pushButton_addRefPoint.setMinimumSize(QtCore.QSize(28, 28))
        self.pushButton_addRefPoint.setMaximumSize(QtCore.QSize(28, 28))
        self.pushButton_addRefPoint.setBaseSize(QtCore.QSize(28, 28))
        self.pushButton_addRefPoint.setObjectName("pushButton_addRefPoint")
        self.horizontalLayout_refPoints.addWidget(self.pushButton_addRefPoint)
        self.label_RefPoints = QtWidgets.QLabel(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_RefPoints.sizePolicy().hasHeightForWidth())
        self.label_RefPoints.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_RefPoints.setFont(font)
        self.label_RefPoints.setObjectName("label_RefPoints")
        self.horizontalLayout_refPoints.addWidget(self.label_RefPoints)
        self.line = QtWidgets.QFrame(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.line.sizePolicy().hasHeightForWidth())
        self.line.setSizePolicy(sizePolicy)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.horizontalLayout_refPoints.addWidget(self.line)
        self.pushButton_openRefPoints = QtWidgets.QPushButton(Form)
        self.pushButton_openRefPoints.setMinimumSize(QtCore.QSize(70, 28))
        self.pushButton_openRefPoints.setMaximumSize(QtCore.QSize(70, 28))
        self.pushButton_openRefPoints.setBaseSize(QtCore.QSize(70, 28))
        self.pushButton_openRefPoints.setObjectName("pushButton_openRefPoints")
        self.horizontalLayout_refPoints.addWidget(self.pushButton_openRefPoints)
        self.pushButton_killAllRefPoints = QtWidgets.QPushButton(Form)
        self.pushButton_killAllRefPoints.setEnabled(False)
        self.pushButton_killAllRefPoints.setMinimumSize(QtCore.QSize(70, 28))
        self.pushButton_killAllRefPoints.setMaximumSize(QtCore.QSize(70, 28))
        self.pushButton_killAllRefPoints.setBaseSize(QtCore.QSize(70, 28))
        self.pushButton_killAllRefPoints.setObjectName("pushButton_killAllRefPoints")
        self.horizontalLayout_refPoints.addWidget(self.pushButton_killAllRefPoints)
        self.verticalLayout.addLayout(self.horizontalLayout_refPoints)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.line_3 = QtWidgets.QFrame(Form)
        self.line_3.setMinimumSize(QtCore.QSize(28, 0))
        self.line_3.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_3.setObjectName("line_3")
        self.horizontalLayout.addWidget(self.line_3)
        self.verticalLayout_points_settings = QtWidgets.QVBoxLayout()
        self.verticalLayout_points_settings.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.verticalLayout_points_settings.setSpacing(6)
        self.verticalLayout_points_settings.setObjectName("verticalLayout_points_settings")
        self.horizontalLayout.addLayout(self.verticalLayout_points_settings)
        self.verticalLayout.addLayout(self.horizontalLayout)
        spacerItem3 = QtWidgets.QSpacerItem(20, 13, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout.addItem(spacerItem3)
        self.gridLayout_Go = QtWidgets.QGridLayout()
        self.gridLayout_Go.setObjectName("gridLayout_Go")
        self.widget_showParams = QtWidgets.QWidget(Form)
        self.widget_showParams.setObjectName("widget_showParams")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.widget_showParams)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.checkBox_legend = QtWidgets.QCheckBox(self.widget_showParams)
        self.checkBox_legend.setAutoExclusive(False)
        self.checkBox_legend.setObjectName("checkBox_legend")
        self.verticalLayout_5.addWidget(self.checkBox_legend)
        self.checkBox_pointRange = QtWidgets.QCheckBox(self.widget_showParams)
        self.checkBox_pointRange.setChecked(False)
        self.checkBox_pointRange.setObjectName("checkBox_pointRange")
        self.verticalLayout_5.addWidget(self.checkBox_pointRange)
        self.gridLayout_Go.addWidget(self.widget_showParams, 0, 0, 1, 1)
        self.pushButton_plotOne = QtWidgets.QPushButton(Form)
        self.pushButton_plotOne.setMinimumSize(QtCore.QSize(90, 32))
        self.pushButton_plotOne.setMaximumSize(QtCore.QSize(90, 32))
        self.pushButton_plotOne.setBaseSize(QtCore.QSize(90, 32))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/buttons/button_plotOne.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_plotOne.setIcon(icon)
        self.pushButton_plotOne.setIconSize(QtCore.QSize(24, 24))
        self.pushButton_plotOne.setObjectName("pushButton_plotOne")
        self.gridLayout_Go.addWidget(self.pushButton_plotOne, 0, 1, 1, 1)
        self.widget_dummy = QtWidgets.QWidget(Form)
        self.widget_dummy.setObjectName("widget_dummy")
        self.gridLayout_Go.addWidget(self.widget_dummy, 0, 3, 1, 1)
        self.pushButton_plotAll = QtWidgets.QPushButton(Form)
        self.pushButton_plotAll.setMinimumSize(QtCore.QSize(90, 32))
        self.pushButton_plotAll.setMaximumSize(QtCore.QSize(90, 32))
        self.pushButton_plotAll.setBaseSize(QtCore.QSize(90, 32))
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/buttons/button_plotAll.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_plotAll.setIcon(icon1)
        self.pushButton_plotAll.setIconSize(QtCore.QSize(20, 20))
        self.pushButton_plotAll.setObjectName("pushButton_plotAll")
        self.gridLayout_Go.addWidget(self.pushButton_plotAll, 0, 2, 1, 1)
        self.verticalLayout.addLayout(self.gridLayout_Go)
        spacerItem4 = QtWidgets.QSpacerItem(20, 43, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.MinimumExpanding)
        self.verticalLayout.addItem(spacerItem4)
        self.horizontalLayout_2.addLayout(self.verticalLayout)
        spacerItem5 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem5)

        self.retranslateUi(Form)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.pushButton_addCurve.setToolTip(_translate("Form", "Add a new curve (Ctrl+N)"))
        self.pushButton_addCurve.setText(_translate("Form", "+"))
        self.pushButton_addCurve.setShortcut(_translate("Form", "Ctrl+N"))
        self.label_enveloppes.setText(_translate("Form", "Critical enveloppes"))
        self.pushButton_killAllCurves.setToolTip(_translate("Form", "Delete all curves (Ctrl+Shift+Del)"))
        self.pushButton_killAllCurves.setText(_translate("Form", "Clear all"))
        self.pushButton_killAllCurves.setShortcut(_translate("Form", "Ctrl+Shift+Del"))
        self.pushButton_addRefPoint.setToolTip(_translate("Form", "Add a new reference point (Ctrl+R)"))
        self.pushButton_addRefPoint.setText(_translate("Form", "+"))
        self.pushButton_addRefPoint.setShortcut(_translate("Form", "Ctrl+R"))
        self.label_RefPoints.setText(_translate("Form", "<u>R</u>eference points"))
        self.pushButton_openRefPoints.setToolTip(_translate("Form", "Import reference points from (x, y) data"))
        self.pushButton_openRefPoints.setText(_translate("Form", "Import"))
        self.pushButton_killAllRefPoints.setToolTip(_translate("Form", "Delete all reference points"))
        self.pushButton_killAllRefPoints.setText(_translate("Form", "Clear all"))
        self.checkBox_legend.setToolTip(_translate("Form", "Check to add legend on plot (Alt+L)"))
        self.checkBox_legend.setText(_translate("Form", "show &legend"))
        self.checkBox_pointRange.setToolTip(_translate("Form", "Check to show range as a light gray line under curve points (Alt+P)"))
        self.checkBox_pointRange.setText(_translate("Form", "show curve &point range"))
        self.pushButton_plotOne.setToolTip(_translate("Form", "Plot current curve and reference points (Ctrl+Enter)"))
        self.pushButton_plotOne.setText(_translate("Form", "Plot"))
        self.pushButton_plotOne.setShortcut(_translate("Form", "Ctrl+Return"))
        self.pushButton_plotAll.setToolTip(_translate("Form", "Plot all curves and points (Crtl+Shift+Enter)"))
        self.pushButton_plotAll.setText(_translate("Form", " Plot all"))
        self.pushButton_plotAll.setShortcut(_translate("Form", "Ctrl+Shift+Return"))

import eccw_gui.images.ressources_rc

if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




#!/usr/bin/env python3
# -*- coding: utf-8 -*-


from PyQt5 import QtWidgets

from eccw_gui.main_app.viewers.dialog_about import Ui_Dialog_About
from eccw_gui import __version__, __authors__, __license__
from eccw_gui import  __url__, __contact__


class About(QtWidgets.QWidget, Ui_Dialog_About):
    """Widget for software informations display."""

    def __init__(self, parent=None):
        super(About, self).__init__(parent)
        self.setupUi(self)
        self.label_version.setText(__version__)
        self.label_authors.setText("\n".join(__authors__))
        self.label_license.setText(__license__)
        color = '#888a85'
        url = "<a href='{}'> GitHub </a>".format(__url__)
        self.label_url.setText(url)
        contact = "<a href='mailto:{}'> {} </a>".format(__contact__, __contact__)
        self.label_contact.setText(contact)
        self.show()


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    myapp = About()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../uis/calculator_main.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(985, 837)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_draw = QtWidgets.QHBoxLayout()
        self.horizontalLayout_draw.setObjectName("horizontalLayout_draw")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_draw.addItem(spacerItem)
        self.label_draw = QtWidgets.QLabel(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.label_draw.sizePolicy().hasHeightForWidth())
        self.label_draw.setSizePolicy(sizePolicy)
        self.label_draw.setMaximumSize(QtCore.QSize(600, 250))
        self.label_draw.setFrameShape(QtWidgets.QFrame.Box)
        self.label_draw.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.label_draw.setText("")
        self.label_draw.setPixmap(QtGui.QPixmap(":/illustrations/illustration_calculator.png"))
        self.label_draw.setScaledContents(True)
        self.label_draw.setObjectName("label_draw")
        self.horizontalLayout_draw.addWidget(self.label_draw)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_draw.addItem(spacerItem1)
        self.verticalLayout.addLayout(self.horizontalLayout_draw)
        spacerItem2 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout.addItem(spacerItem2)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem3 = QtWidgets.QSpacerItem(19, 107, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem3)
        self.horizontalLayout_context = QtWidgets.QHBoxLayout()
        self.horizontalLayout_context.setObjectName("horizontalLayout_context")
        self.horizontalLayout.addLayout(self.horizontalLayout_context)
        self.groupBox_parameters = QtWidgets.QGroupBox(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_parameters.sizePolicy().hasHeightForWidth())
        self.groupBox_parameters.setSizePolicy(sizePolicy)
        self.groupBox_parameters.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBox_parameters.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.groupBox_parameters.setFont(font)
        self.groupBox_parameters.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.groupBox_parameters.setObjectName("groupBox_parameters")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox_parameters)
        self.gridLayout.setObjectName("gridLayout")
        self.label_beta = QtWidgets.QLabel(self.groupBox_parameters)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_beta.sizePolicy().hasHeightForWidth())
        self.label_beta.setSizePolicy(sizePolicy)
        self.label_beta.setMaximumSize(QtCore.QSize(12, 24))
        self.label_beta.setText("")
        self.label_beta.setPixmap(QtGui.QPixmap(":/params/params_beta.png"))
        self.label_beta.setScaledContents(True)
        self.label_beta.setObjectName("label_beta")
        self.gridLayout.addWidget(self.label_beta, 1, 2, 1, 1)
        self.horizontalLayout_alpha = QtWidgets.QHBoxLayout()
        self.horizontalLayout_alpha.setSpacing(0)
        self.horizontalLayout_alpha.setObjectName("horizontalLayout_alpha")
        self.gridLayout.addLayout(self.horizontalLayout_alpha, 0, 5, 1, 1)
        self.horizontalLayout_phiB = QtWidgets.QHBoxLayout()
        self.horizontalLayout_phiB.setSpacing(0)
        self.horizontalLayout_phiB.setObjectName("horizontalLayout_phiB")
        self.gridLayout.addLayout(self.horizontalLayout_phiB, 0, 9, 1, 1)
        self.horizontalLayout_beta = QtWidgets.QHBoxLayout()
        self.horizontalLayout_beta.setSpacing(0)
        self.horizontalLayout_beta.setObjectName("horizontalLayout_beta")
        self.gridLayout.addLayout(self.horizontalLayout_beta, 1, 5, 1, 1)
        self.horizontalLayout_phiD = QtWidgets.QHBoxLayout()
        self.horizontalLayout_phiD.setSpacing(0)
        self.horizontalLayout_phiD.setObjectName("horizontalLayout_phiD")
        self.gridLayout.addLayout(self.horizontalLayout_phiD, 1, 9, 1, 1)
        self.label_alpha = QtWidgets.QLabel(self.groupBox_parameters)
        self.label_alpha.setMaximumSize(QtCore.QSize(12, 24))
        self.label_alpha.setText("")
        self.label_alpha.setPixmap(QtGui.QPixmap(":/params/params_alpha.png"))
        self.label_alpha.setScaledContents(True)
        self.label_alpha.setObjectName("label_alpha")
        self.gridLayout.addWidget(self.label_alpha, 0, 2, 1, 1)
        self.label_phiD = QtWidgets.QLabel(self.groupBox_parameters)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_phiD.sizePolicy().hasHeightForWidth())
        self.label_phiD.setSizePolicy(sizePolicy)
        self.label_phiD.setMaximumSize(QtCore.QSize(20, 24))
        self.label_phiD.setPixmap(QtGui.QPixmap(":/params/params_phiD.png"))
        self.label_phiD.setScaledContents(True)
        self.label_phiD.setObjectName("label_phiD")
        self.gridLayout.addWidget(self.label_phiD, 1, 8, 1, 1)
        self.label_phiB = QtWidgets.QLabel(self.groupBox_parameters)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_phiB.sizePolicy().hasHeightForWidth())
        self.label_phiB.setSizePolicy(sizePolicy)
        self.label_phiB.setMaximumSize(QtCore.QSize(20, 24))
        self.label_phiB.setText("")
        self.label_phiB.setPixmap(QtGui.QPixmap(":/params/params_phiB.png"))
        self.label_phiB.setScaledContents(True)
        self.label_phiB.setObjectName("label_phiB")
        self.gridLayout.addWidget(self.label_phiB, 0, 8, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.groupBox_parameters)
        self.label_2.setMaximumSize(QtCore.QSize(6, 24))
        self.label_2.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 1, 0, 1, 1)
        self.label_1 = QtWidgets.QLabel(self.groupBox_parameters)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_1.sizePolicy().hasHeightForWidth())
        self.label_1.setSizePolicy(sizePolicy)
        self.label_1.setMaximumSize(QtCore.QSize(6, 24))
        self.label_1.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_1.setObjectName("label_1")
        self.gridLayout.addWidget(self.label_1, 0, 0, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.groupBox_parameters)
        self.label_4.setMinimumSize(QtCore.QSize(12, 0))
        self.label_4.setMaximumSize(QtCore.QSize(12, 24))
        self.label_4.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_4.setObjectName("label_4")
        self.gridLayout.addWidget(self.label_4, 1, 6, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.groupBox_parameters)
        self.label_3.setMinimumSize(QtCore.QSize(12, 0))
        self.label_3.setMaximumSize(QtCore.QSize(12, 24))
        self.label_3.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 0, 6, 1, 1)
        self.checkBox_alpha = QtWidgets.QCheckBox(self.groupBox_parameters)
        self.checkBox_alpha.setMaximumSize(QtCore.QSize(20, 16777215))
        self.checkBox_alpha.setText("")
        self.checkBox_alpha.setChecked(True)
        self.checkBox_alpha.setAutoExclusive(True)
        self.checkBox_alpha.setObjectName("checkBox_alpha")
        self.gridLayout.addWidget(self.checkBox_alpha, 0, 1, 1, 1)
        self.checkBox_beta = QtWidgets.QCheckBox(self.groupBox_parameters)
        self.checkBox_beta.setMaximumSize(QtCore.QSize(20, 16777215))
        self.checkBox_beta.setText("")
        self.checkBox_beta.setAutoExclusive(True)
        self.checkBox_beta.setObjectName("checkBox_beta")
        self.gridLayout.addWidget(self.checkBox_beta, 1, 1, 1, 1)
        self.checkBox_phiB = QtWidgets.QCheckBox(self.groupBox_parameters)
        self.checkBox_phiB.setMaximumSize(QtCore.QSize(20, 16777215))
        self.checkBox_phiB.setText("")
        self.checkBox_phiB.setAutoExclusive(True)
        self.checkBox_phiB.setObjectName("checkBox_phiB")
        self.gridLayout.addWidget(self.checkBox_phiB, 0, 7, 1, 1)
        self.checkBox_phiD = QtWidgets.QCheckBox(self.groupBox_parameters)
        self.checkBox_phiD.setMaximumSize(QtCore.QSize(20, 16777215))
        self.checkBox_phiD.setText("")
        self.checkBox_phiD.setAutoExclusive(True)
        self.checkBox_phiD.setObjectName("checkBox_phiD")
        self.gridLayout.addWidget(self.checkBox_phiD, 1, 7, 1, 1)
        self.horizontalLayout.addWidget(self.groupBox_parameters)
        self.groupBox_fluids = QtWidgets.QGroupBox(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_fluids.sizePolicy().hasHeightForWidth())
        self.groupBox_fluids.setSizePolicy(sizePolicy)
        self.groupBox_fluids.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBox_fluids.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.groupBox_fluids.setFont(font)
        self.groupBox_fluids.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.groupBox_fluids.setFlat(False)
        self.groupBox_fluids.setCheckable(True)
        self.groupBox_fluids.setChecked(False)
        self.groupBox_fluids.setObjectName("groupBox_fluids")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox_fluids)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.horizontalLayout_lamdaB = QtWidgets.QHBoxLayout()
        self.horizontalLayout_lamdaB.setSpacing(0)
        self.horizontalLayout_lamdaB.setObjectName("horizontalLayout_lamdaB")
        self.gridLayout_2.addLayout(self.horizontalLayout_lamdaB, 0, 2, 1, 1)
        self.label_lamdaB = QtWidgets.QLabel(self.groupBox_fluids)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_lamdaB.sizePolicy().hasHeightForWidth())
        self.label_lamdaB.setSizePolicy(sizePolicy)
        self.label_lamdaB.setMaximumSize(QtCore.QSize(30, 24))
        self.label_lamdaB.setPixmap(QtGui.QPixmap(":/params/params_lamdaB.png"))
        self.label_lamdaB.setScaledContents(True)
        self.label_lamdaB.setObjectName("label_lamdaB")
        self.gridLayout_2.addWidget(self.label_lamdaB, 0, 1, 1, 1)
        self.label_rhof = QtWidgets.QLabel(self.groupBox_fluids)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_rhof.sizePolicy().hasHeightForWidth())
        self.label_rhof.setSizePolicy(sizePolicy)
        self.label_rhof.setMaximumSize(QtCore.QSize(24, 24))
        self.label_rhof.setText("")
        self.label_rhof.setPixmap(QtGui.QPixmap(":/params/params_rhof.png"))
        self.label_rhof.setScaledContents(True)
        self.label_rhof.setObjectName("label_rhof")
        self.gridLayout_2.addWidget(self.label_rhof, 0, 4, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.groupBox_fluids)
        self.label_6.setMaximumSize(QtCore.QSize(6, 24))
        self.label_6.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_6.setObjectName("label_6")
        self.gridLayout_2.addWidget(self.label_6, 1, 0, 1, 1)
        self.horizontalLayout_lamdaD = QtWidgets.QHBoxLayout()
        self.horizontalLayout_lamdaD.setSpacing(0)
        self.horizontalLayout_lamdaD.setObjectName("horizontalLayout_lamdaD")
        self.gridLayout_2.addLayout(self.horizontalLayout_lamdaD, 1, 2, 1, 1)
        self.horizontalLayout_rhosr = QtWidgets.QHBoxLayout()
        self.horizontalLayout_rhosr.setSpacing(0)
        self.horizontalLayout_rhosr.setObjectName("horizontalLayout_rhosr")
        self.gridLayout_2.addLayout(self.horizontalLayout_rhosr, 1, 5, 1, 1)
        self.horizontalLayout_rhof = QtWidgets.QHBoxLayout()
        self.horizontalLayout_rhof.setSpacing(0)
        self.horizontalLayout_rhof.setObjectName("horizontalLayout_rhof")
        self.gridLayout_2.addLayout(self.horizontalLayout_rhof, 0, 5, 1, 1)
        self.label_rhosr = QtWidgets.QLabel(self.groupBox_fluids)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_rhosr.sizePolicy().hasHeightForWidth())
        self.label_rhosr.setSizePolicy(sizePolicy)
        self.label_rhosr.setMaximumSize(QtCore.QSize(24, 24))
        self.label_rhosr.setText("")
        self.label_rhosr.setPixmap(QtGui.QPixmap(":/params/params_rhosr.png"))
        self.label_rhosr.setScaledContents(True)
        self.label_rhosr.setObjectName("label_rhosr")
        self.gridLayout_2.addWidget(self.label_rhosr, 1, 4, 1, 1)
        self.label_lamdaD = QtWidgets.QLabel(self.groupBox_fluids)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_lamdaD.sizePolicy().hasHeightForWidth())
        self.label_lamdaD.setSizePolicy(sizePolicy)
        self.label_lamdaD.setMaximumSize(QtCore.QSize(30, 24))
        self.label_lamdaD.setText("")
        self.label_lamdaD.setPixmap(QtGui.QPixmap(":/params/params_lamdaD.png"))
        self.label_lamdaD.setScaledContents(True)
        self.label_lamdaD.setObjectName("label_lamdaD")
        self.gridLayout_2.addWidget(self.label_lamdaD, 1, 1, 1, 1)
        self.label_7 = QtWidgets.QLabel(self.groupBox_fluids)
        self.label_7.setMinimumSize(QtCore.QSize(12, 0))
        self.label_7.setMaximumSize(QtCore.QSize(12, 24))
        self.label_7.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_7.setObjectName("label_7")
        self.gridLayout_2.addWidget(self.label_7, 0, 3, 1, 1)
        self.label_8 = QtWidgets.QLabel(self.groupBox_fluids)
        self.label_8.setMinimumSize(QtCore.QSize(12, 0))
        self.label_8.setMaximumSize(QtCore.QSize(12, 24))
        self.label_8.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_8.setObjectName("label_8")
        self.gridLayout_2.addWidget(self.label_8, 1, 3, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.groupBox_fluids)
        self.label_5.setMaximumSize(QtCore.QSize(6, 24))
        self.label_5.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_5.setObjectName("label_5")
        self.gridLayout_2.addWidget(self.label_5, 0, 0, 1, 1)
        self.horizontalLayout.addWidget(self.groupBox_fluids)
        spacerItem4 = QtWidgets.QSpacerItem(20, 107, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem4)
        self.verticalLayout.addLayout(self.horizontalLayout)
        spacerItem5 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout.addItem(spacerItem5)
        self.horizontalLayout_GoClear = QtWidgets.QHBoxLayout()
        self.horizontalLayout_GoClear.setObjectName("horizontalLayout_GoClear")
        spacerItem6 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_GoClear.addItem(spacerItem6)
        self.pushButton_Go = QtWidgets.QPushButton(Form)
        self.pushButton_Go.setMinimumSize(QtCore.QSize(100, 32))
        self.pushButton_Go.setMaximumSize(QtCore.QSize(100, 32))
        self.pushButton_Go.setBaseSize(QtCore.QSize(80, 32))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/buttons/button_compute.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_Go.setIcon(icon)
        self.pushButton_Go.setIconSize(QtCore.QSize(20, 20))
        self.pushButton_Go.setObjectName("pushButton_Go")
        self.horizontalLayout_GoClear.addWidget(self.pushButton_Go)
        self.pushButton_Clear = QtWidgets.QPushButton(Form)
        self.pushButton_Clear.setMinimumSize(QtCore.QSize(54, 32))
        self.pushButton_Clear.setMaximumSize(QtCore.QSize(54, 32))
        self.pushButton_Clear.setBaseSize(QtCore.QSize(54, 32))
        self.pushButton_Clear.setObjectName("pushButton_Clear")
        self.horizontalLayout_GoClear.addWidget(self.pushButton_Clear)
        spacerItem7 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_GoClear.addItem(spacerItem7)
        self.verticalLayout.addLayout(self.horizontalLayout_GoClear)
        self.horizontalLayout_Results = QtWidgets.QHBoxLayout()
        self.horizontalLayout_Results.setSizeConstraint(QtWidgets.QLayout.SetMaximumSize)
        self.horizontalLayout_Results.setObjectName("horizontalLayout_Results")
        spacerItem8 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_Results.addItem(spacerItem8)
        self.textEdit_results = QtWidgets.QTextEdit(Form)
        self.textEdit_results.setMinimumSize(QtCore.QSize(600, 200))
        self.textEdit_results.setMaximumSize(QtCore.QSize(600, 16777215))
        self.textEdit_results.setToolTip("")
        self.textEdit_results.setReadOnly(True)
        self.textEdit_results.setObjectName("textEdit_results")
        self.horizontalLayout_Results.addWidget(self.textEdit_results)
        spacerItem9 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_Results.addItem(spacerItem9)
        self.verticalLayout.addLayout(self.horizontalLayout_Results)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.groupBox_parameters.setTitle(_translate("Form", "Select parameter to calculate"))
        self.label_beta.setToolTip(_translate("Form", "Basal slope [deg]"))
        self.label_alpha.setToolTip(_translate("Form", "Critical surface slope [deg]"))
        self.label_phiD.setToolTip(_translate("Form", "Basal friction angle [deg]"))
        self.label_phiB.setToolTip(_translate("Form", "Bulk friction angle [deg]"))
        self.label_2.setText(_translate("Form", "<sup>2</sup>"))
        self.label_1.setText(_translate("Form", "<sup>1</sup>"))
        self.label_4.setText(_translate("Form", "<sup>4</sup>"))
        self.label_3.setText(_translate("Form", "<sup>3</sup>"))
        self.checkBox_alpha.setToolTip(_translate("Form", "Check for calculate critical surface slope (F1)"))
        self.checkBox_alpha.setShortcut(_translate("Form", "F1"))
        self.checkBox_beta.setToolTip(_translate("Form", "Check for calculate basal slope (F2)"))
        self.checkBox_beta.setShortcut(_translate("Form", "F2"))
        self.checkBox_phiB.setToolTip(_translate("Form", "Check for calculate bulk friction angle (F3)"))
        self.checkBox_phiB.setShortcut(_translate("Form", "F3"))
        self.checkBox_phiD.setToolTip(_translate("Form", "Check for calculate basal friction angle (F4)"))
        self.checkBox_phiD.setShortcut(_translate("Form", "F4"))
        self.groupBox_fluids.setToolTip(_translate("Form", "Check to activate fluids pore pressure parameters (Alt F)"))
        self.groupBox_fluids.setTitle(_translate("Form", "&Fluids pore pressure"))
        self.label_lamdaB.setToolTip(_translate("Form", "Bulk fluids overpressure ratio"))
        self.label_rhof.setToolTip(_translate("Form", "Volumetric mass density of fluids"))
        self.label_6.setText(_translate("Form", "<sup>6</sup>"))
        self.label_rhosr.setToolTip(_translate("Form", "Volumetric mass density of saturated rock"))
        self.label_lamdaD.setToolTip(_translate("Form", "Bulk fluids overpressure ratio"))
        self.label_7.setText(_translate("Form", "<sup>7</sup>"))
        self.label_8.setText(_translate("Form", "<sup>8</sup>"))
        self.label_5.setText(_translate("Form", "<sup>5</sup>"))
        self.pushButton_Go.setToolTip(_translate("Form", "Launch calculation (Crtl+Enter)"))
        self.pushButton_Go.setText(_translate("Form", "Compute"))
        self.pushButton_Go.setShortcut(_translate("Form", "Ctrl+Return"))
        self.pushButton_Clear.setToolTip(_translate("Form", "Clear inputs and results fields (Crtl+Del)"))
        self.pushButton_Clear.setText(_translate("Form", "Clear"))
        self.pushButton_Clear.setShortcut(_translate("Form", "Ctrl+Del"))
        self.textEdit_results.setHtml(_translate("Form", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Cantarell\'; font-size:11pt; font-weight:400; font-style:normal;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p></body></html>"))

import eccw_gui.images.ressources_rc

if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from PyQt5 import QtCore, QtGui, QtWidgets
from collections import OrderedDict
from os.path import dirname, realpath
import sys
import webbrowser

from eccw_gui.main_app.viewers.main import Ui_Form
from eccw_gui.main_app.controllers.dialog_about import About
from eccw_gui.calculator_app.controllers.calculator_main import CalculatorController
from eccw_gui.plot_app.controllers.plot_main import PlotController
from eccw_gui.shared.wrappers import WrapperDict
from eccw_gui.shared.file_management import EccwFile, open_pdf
from eccw_gui.shared.tools import graph_print


class MainController(QtWidgets.QWidget, Ui_Form, WrapperDict):
    """Main window of ECCW app."""
    def __init__(self, parent=None, **kwargs):
        super(MainController, self).__init__(parent)
        self.setupUi(self)
        #self.setWindowTitle("ECCW")
        #self.set_app_icon()
        #self.app_icon = self._make_app_icon()
        #self.setWindowIcon(self.app_icon)
        self.current_dir = QtCore.QDir.homePath()
        self.mime_types = ("Fichier eccw (*.%s);;Tout les Fichiers (*.*)"
                           % EccwFile.mime)
        # Set calculator tab.
        self.calculator = CalculatorController()
        layoutC = QtWidgets.QVBoxLayout()
        layoutC.addWidget(self.calculator)
        self.tabWidget_main.widget(0).setLayout(layoutC)
        # Set plot tab.
        self.plot = PlotController()
        #self.plot.plot_window.setWindowIcon(self.app_icon)
        layoutP = QtWidgets.QVBoxLayout()
        layoutP.addWidget(self.plot)
        self.tabWidget_main.widget(1).setLayout(layoutP)
        # Define behaviours
        self.pushButton_Open.clicked.connect(self.load_session)
        self.pushButton_Save.clicked.connect(self.save_session)
        self.pushButton_About.clicked.connect(self.click_about)
        self.pushButton_Documentation.clicked.connect(self.click_doc)
        # Defines keyboard shortcuts.
        QtWidgets.QShortcut(QtGui.QKeySequence("Ctrl+Q"), self, self.close)
        TabW = self.tabWidget_main
        QtWidgets.QShortcut(QtGui.QKeySequence("Ctrl+Page up"), self,
                        lambda: TabW.setCurrentIndex(TabW.currentIndex()-1))
        QtWidgets.QShortcut(QtGui.QKeySequence("Ctrl+Page down"), self,
                        lambda: TabW.setCurrentIndex(TabW.currentIndex()+1))
        # Dictionnary (WrapperDict)
        self.dict = OrderedDict([
            ("calculator", self.calculator),
            ("plot",       self.plot)
        ])
        # Fill values with kwargs.
        if kwargs:
            self.set_params(**kwargs)
        self.show()

    def closeEvent(self, event):
        """Close plot window when closing main window."""
        self.plot.plot_window.close()
        event.accept()

    def _make_app_icon(self):
        """Set main window icon displayed in pannel, overview mode, etc..."""
        app_icon = QtGui.QIcon(":/icons/icon_eccw.svg")
        #app_icon.addFile(QtGui.QPixmap(":/icons/icon_eccw.svg"))
        #app_icon.addPixmap(QtGui.QPixmap(":/icons/icon_eccw.svg"))
        app_icon.addPixmap(QtGui.QPixmap(":/icons/icon_eccw_16x16.png"))
        app_icon.addPixmap(QtGui.QPixmap(":/icons/icon_eccw_24x24.png"))
        app_icon.addPixmap(QtGui.QPixmap(":/icons/icon_eccw_32x32.png"))
        app_icon.addPixmap(QtGui.QPixmap(":/icons/icon_eccw_48x48.png"))
        app_icon.addPixmap(QtGui.QPixmap(":/icons/icon_eccw_128x128.png"))
        app_icon.addPixmap(QtGui.QPixmap(":/icons/icon_eccw_256x256.png"))
        app_icon.addPixmap(QtGui.QPixmap(":/icons/icon_eccw_512x512.png"))
        return app_icon

    def click_about(self):
        self.about = About()

    def click_doc(self):
        open_pdf("/eccw_gui/documentation/ECCW.pdf")

    # Save and load file management.

    def load_session(self):
        OpenDialog = QtWidgets.QFileDialog.getOpenFileName
        out_opendialog = OpenDialog(
            self,
            "Open file",
            self.current_dir,
            self.mime_types
            )
        file_name = out_opendialog[0]
        if file_name == "":
            return
        self.current_dir = dirname(realpath(file_name))
        eccwf = EccwFile(filename=file_name)
        if eccwf.values is None:
            message = ("Wrong file type.\n"
                       "Chosen file must be a *.eccw mime type.")
            QtWidgets.QMessageBox.about(self, "Error", message)
            return
        self.set_params(**eccwf.values)

    def save_session(self):
        SaveDialog = QtWidgets.QFileDialog.getSaveFileName
        file_name, _ = SaveDialog(self, "Save file", self.current_dir,
                                  self.mime_types)
        if file_name:
            eccwf = EccwFile(data=self.get_params())
            eccwf.save(file_name)


if __name__ == "__main__":
    eccwf = EccwFile(filename="../../../tests/data/test.eccw")
    params = eccwf.values
    try:
        app = QtWidgets.QApplication(sys.argv)
        myapp = MainController(**params)
        myapp.current_dir = "/home/bmary/Programmation/eccw/tests/"
        myapp.plot.current_dir = "/home/bmary/Programmation/eccw/tests/"
        sys.exit(app.exec_())
    finally:
        pass
        print("params =")
        graph_print(myapp.get_select())



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../uis/plot_window.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_PlotWindow(object):
    def setupUi(self, PlotWindow):
        PlotWindow.setObjectName("PlotWindow")
        PlotWindow.resize(800, 600)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/icon_eccw_512x512.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        PlotWindow.setWindowIcon(icon)
        self.verticalLayout = QtWidgets.QVBoxLayout(PlotWindow)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.verticalLayout_plot = QtWidgets.QVBoxLayout()
        self.verticalLayout_plot.setObjectName("verticalLayout_plot")
        self.verticalLayout.addLayout(self.verticalLayout_plot)
        self.verticalLayout_toolbox = QtWidgets.QVBoxLayout()
        self.verticalLayout_toolbox.setObjectName("verticalLayout_toolbox")
        self.verticalLayout.addLayout(self.verticalLayout_toolbox)

        self.retranslateUi(PlotWindow)
        QtCore.QMetaObject.connectSlotsByName(PlotWindow)

    def retranslateUi(self, PlotWindow):
        _translate = QtCore.QCoreApplication.translate
        PlotWindow.setWindowTitle(_translate("PlotWindow", "ECCW plot"))

import eccw_gui.images.ressources_rc

if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    PlotWindow = QtWidgets.QWidget()
    ui = Ui_PlotWindow()
    ui.setupUi(PlotWindow)
    PlotWindow.show()
    sys.exit(app.exec_())




#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from PyQt5 import QtWidgets


from eccw_gui.shared.viewers.comboBox_line import Ui_Form as UiLine
from eccw_gui.shared.viewers.comboBox_point import Ui_Form as UiPoint
from eccw_gui.shared.viewers.comboBox_colorMap import Ui_Form as UiCmap


class ComboBox(object):
    """Abstract class."""

    parser = dict()

    def get_params(self):
        return self.comboBox.currentText()

    def set_params(self, value):
        i = self.comboBox.findText(str(value))
        if i >= 0:
            self.comboBox.setCurrentIndex(i)
        else:
            raise TypeError(
                self.__class__.__name__
                + "() gets unknown style argument '"
                + str(value)
                + "'."
            )

    def get_select(self):
        return self.parser[self.get_params()]


class ComboBoxLine(QtWidgets.QWidget, UiLine, ComboBox):
    """Combo box widget for line style settings.

    Arguments:
    Awaits a single string value among the following list:
    * continuous
    * dotted
    * dashed
    * dash dotted

    This is a Qt derived object.
    """

    def __init__(self, *args):
        super(ComboBoxLine, self).__init__()
        self.parser = {
            "continuous": "-",
            "dotted": ":",
            "dashed": "--",
            "dash dotted": "-.",
        }
        self.setupUi(self)
        # Fill values with args
        if args:
            self.set_params(*args)
        self.show()


class ComboBoxPoint(QtWidgets.QWidget, UiPoint, ComboBox):
    """Combo box widget for point style settings.

    Arguments:
    Awaits a single string value among the following list:
    * circle   or c
    * square   or s
    * diamond  or d
    * triangle or t
    * star     or *
    * cross    or +
    * pentagon or p

    This is a Qt derived object.
    """

    def __init__(self, *args):
        super(ComboBoxPoint, self).__init__()
        self.setupUi(self)
        # Fill values with args
        self.shortcuts_parser = {
            "c": "circle",
            "s": "square",
            "d": "diamond",
            "t": "triangle",
            "*": "star",
            "+": "cross",
            "p": "pentagon",
        }
        self.parser = {
            "circle": "o",
            "square": "s",
            "diamond": "D",
            "triangle": "^",
            "star": "*",
            "cross": "+",
            "pentagon": "p",
        }
        if args:
            self.set_params(*args)
        self.show()

    def set_params(self, value):
        value = self.shortcuts_parser.get(value, value)
        ComboBoxLine.set_params(self, value)


class ComboBoxColorMap(QtWidgets.QWidget, UiCmap, ComboBox):
    """Combo box widget for colormap settings.

    Arguments:
    Awaits a single string value among the following list
    (All are matplotlib colormaps):
    * Gray
    * Hot
    * Winter
    * Gnuplot
    * Gnuplot2
    * Magma
    * Inferno
    * Plasma
    * Viridis

    This is a Qt derived object.
    """

    def __init__(self, *args):
        super(ComboBoxColorMap, self).__init__()
        self.setupUi(self)
        self.parser = {
            "Gray": "Greys",
            "Hot": "hot",
            "Winter": "winter",
            "Gnuplot": "gnuplot",
            "Gnuplot2": "gnuplot2",
            "Magma": "magma",
            "Inferno": "inferno",
            "Plasma": "plasma",
            "Viridis": "viridis",
        }
        # Fill values with args
        if args:
            self.set_params(*args)
        self.show()


if __name__ == "__main__":
    import sys

    try:
        app = QtWidgets.QApplication(sys.argv)
        myapp = ComboBoxColorMap("Inferno")
        #        myapp = ComboBoxPoint('*')
        #        myapp = ComboBoxLine("dashed")
        sys.exit(app.exec_())
    finally:
        print("params =", myapp.get_params())
        print("select =", myapp.get_select())



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from PyQt5 import QtWidgets, QtGui
from collections import OrderedDict

from eccw_gui.plot_app.viewers.curve_settings import Ui_Form
from eccw_gui.plot_app.controllers.curve_graphicSettings import (
    SwitchCurveGraphicSettings,
)
from eccw_gui.plot_app.controllers.point_settings import CurvePointSettings
from eccw_gui.shared.controllers.lineEdit import SwitchScalarRange
from eccw_gui.shared.controllers.groupBox import GroupBoxContext
from eccw_gui.shared.controllers.lineEdit import StringLineEdit
from eccw_gui.shared.controllers.label import Label
from eccw_gui.shared.wrappers import Wrapper, WrapperDict, WrapperList
from eccw_gui.shared.tools import graph_print


class CurveController(QtWidgets.QWidget, Ui_Form, WrapperDict):
    """Widget for curve parameters and settings entry.

    Keyword arguments:
    label         -- awaits a string label.
    context       -- awaits a string among 'Compression' and 'Extension'.
    fluids        -- awaits a boolean.
    phiB          -- awaits a dict of keyword arguments for a SwitchScalarRange
                     element.
    phiD          -- awaits a dict of keyword arguments for a SwitchScalarRange
                     element.
    delta_lambdaB -- awaits a dict of keyword arguments for a SwitchScalarRange
                     element.
    delta_lambdaD -- awaits a dict of keyword arguments for a SwitchScalarRange
                     element.
    rho_f         -- awaits a dict of keyword arguments for a SwitchScalarRange
                     element.
    rho_sr        -- awaits a dict of keyword arguments for a SwitchScalarRange
                     element.
    settings      -- awaits a dict of keyword arguments for a
                     SwitchCurveGraphicSettings element.
    points        -- awaits a dict of keyword arguments for a
                     CurvePointSettings element.

    This is a Qt derived object.
    """

    def __init__(self, **kwargs):
        super(CurveController, self).__init__()
        self.setupUi(self)
        self.setAutoFillBackground(True)  # Needed by QTabWidget in plot_main.
        # Init local attributs.
        self.closed = False
        # Init additional objects
        # Mechanic.
        self.phiB = SwitchScalarRange(id="phiB")
        self.phiD = SwitchScalarRange(id="phiD")
        # Fluids.
        self.fluids = Wrapper(
            False,
            process=lambda x: eval(str(x)),
            action=self.groupBox_fluids.setChecked,
        )
        self.delta_lambdaB = SwitchScalarRange(id="delta_lambdaB")
        self.delta_lambdaD = SwitchScalarRange(id="delta_lambdaD")
        self.rho_f = SwitchScalarRange(id="rho_f")
        self.rho_sr = SwitchScalarRange(id="rho_sr")
        self.context = GroupBoxContext()
        # store name of ranged parameter if any.
        self.range = Wrapper(None)  # , process=self._set_ranged)
        # Label
        self.label_label = Label("la<u>b</u>el")
        self.label = StringLineEdit()
        # Graphic settings.
        self.settings = SwitchCurveGraphicSettings()
        # Curve points
        self.points = WrapperList()
        # Put additional elements in self.
        self.horizontalLayout_phiB.addWidget(self.phiB)
        self.horizontalLayout_phiD.addWidget(self.phiD)
        self.horizontalLayout_lamdaB.addWidget(self.delta_lambdaB)
        self.horizontalLayout_lamdaD.addWidget(self.delta_lambdaD)
        self.horizontalLayout_rhof.addWidget(self.rho_f)
        self.horizontalLayout_rhosr.addWidget(self.rho_sr)
        self.horizontalLayout_context.addWidget(self.context)
        self.verticalLayout_settings.addWidget(self.settings)
        self.horizontalLayout_label.addWidget(self.label_label)
        self.horizontalLayout_label.addWidget(self.label)
        # Shortcuts
        QtWidgets.QShortcut(
            QtGui.QKeySequence("Alt+B"), self, self.label.lineEdit.setFocus,
        )
        # List for SwitchScalarRange objects control.
        self.param_object_list = [
            self.phiB,
            self.phiD,
            self.delta_lambdaB,
            self.delta_lambdaD,
            self.rho_f,
            self.rho_sr,
        ]
        # Booleans
        self.split_curves = Wrapper(
            False,
            process=lambda x: eval(str(x)),
            action=self.checkBox_splittedCurves.setChecked,
        )
        self.reverse_cmap = Wrapper(
            False,
            process=lambda x: eval(str(x)),
            action=self.checkBox_reverseColormap.setChecked,
        )
        # Define events
        self.pushButton_addCurvePoint.clicked.connect(self.add_curve_point)
        self.pushButton_killAllCurvePoints.clicked.connect(self.kill_all_curve_point)
        self.checkBox_splittedCurves.clicked.connect(self._auto_set_settings)
        self.groupBox_fluids.clicked.connect(self._fluids_changed)
        self.checkBox_splittedCurves.clicked.connect(self._split_curve_changed)
        self.checkBox_reverseColormap.clicked.connect(self._reverse_cm_changed)
        tmp = lambda elt: lambda: self._there_can_be_only_one(elt)
        for elt in self.param_object_list:
            elt.pushButton.clicked.connect(tmp(elt))
        self.pushButton_kill.clicked.connect(self._set_closed)
        # Shortcuts for edit parameters.
        self._set_switchLineEdit_shortcuts(self.phiB, "Ctrl+3", "Ctrl+Alt+3")
        self._set_switchLineEdit_shortcuts(self.phiD, "Ctrl+4", "Ctrl+Alt+4")
        self._set_switchLineEdit_shortcuts(self.delta_lambdaB, "Ctrl+5", "Ctrl+Alt+5")
        self._set_switchLineEdit_shortcuts(self.delta_lambdaD, "Ctrl+6", "Ctrl+Alt+6")
        self._set_switchLineEdit_shortcuts(self.rho_f, "Ctrl+7", "Ctrl+Alt+7")
        self._set_switchLineEdit_shortcuts(self.rho_sr, "Ctrl+8", "Ctrl+Alt+8")
        # Dictionnary (WrapperDict)
        self.dict = OrderedDict(
            [
                ("label", self.label),
                ("context", self.context),
                ("fluids", self.fluids),
                ("range", self.range),
                ("split_curves", self.split_curves),
                ("reverse_cmap", self.reverse_cmap),
                ("phiB", self.phiB),
                ("phiD", self.phiD),
                ("delta_lambdaB", self.delta_lambdaB),
                ("delta_lambdaD", self.delta_lambdaD),
                ("rho_f", self.rho_f),
                ("rho_sr", self.rho_sr),
                ("settings", self.settings),
                ("points", self.points),
            ]
        )
        # Fill values with kwargs
        if kwargs:
            self.set_params(**kwargs)
        self._auto_set_settings()
        self.show()

    def set_params(self, **kwargs):
        # There must be as many points as asked to set.
        self.kill_all_curve_point()
        # Using dict get method allows to pass single parameters.
        N = len(kwargs.get("points", []))
        for i in range(N):
            self.add_curve_point()
        WrapperDict.set_params(self, **kwargs)
        for obj in self.param_object_list:
            if obj.focus.value == "range":
                self._there_can_be_only_one(obj)
                break

    # Events management.

    def _set_switchLineEdit_shortcuts(self, widget, scalar_key, range_key):
        QtWidgets.QShortcut(
            QtGui.QKeySequence(scalar_key),
            self,
            lambda: self._there_can_be_multiple_scalar_focus(widget),
        )
        QtWidgets.QShortcut(
            QtGui.QKeySequence(range_key),
            self,
            lambda: self._there_can_be_only_one_range_focus(widget),
        )
        widget.pushButton.setToolTip(
            widget.pushButton.toolTip() + f" ({scalar_key} | {range_key})"
        )

    def _set_closed(self):
        self.closed = True

    def _is_range_activated(self):
        return not all([Obj.focus.value == "scalar" for Obj in self.param_object_list])

    def _there_can_be_only_one(self, elt):
        if elt.focus.value == "scalar":
            self.range.value = None
        else:
            self.range.value = elt.id.value
        for Obj in self.param_object_list:
            if Obj is not elt:
                Obj.set_scalar_visible(True)
        self._auto_set_settings()

    def _there_can_be_only_one_range_focus(self, elt):
        elt.set_focus_on_range()
        self._there_can_be_only_one(elt)

    def _there_can_be_multiple_scalar_focus(self, elt):
        elt.set_focus_on_scalar()
        self._there_can_be_only_one(elt)

    def _auto_set_settings(self):
        # Next line solves blinking when switching from a focus to another.
        self.settings.set_visible_manual("")
        if self._is_range_activated():
            self.settings.set_visible_manual("range")
            self.checkBox_splittedCurves.setEnabled(False)
            self.checkBox_reverseColormap.setEnabled(True)
        else:
            self.checkBox_splittedCurves.setEnabled(True)
            self.checkBox_reverseColormap.setEnabled(False)
            if self.checkBox_splittedCurves.isChecked():
                self.settings.set_visible_manual("double")
            else:
                self.settings.set_visible_manual("default")

    def _fluids_changed(self):
        self.fluids.value = self.groupBox_fluids.isChecked()

    def _split_curve_changed(self):
        self.split_curves.value = self.checkBox_splittedCurves.isChecked()

    def _reverse_cm_changed(self):
        self.reverse_cmap.value = self.checkBox_reverseColormap.isChecked()

    # Curve Points management.

    def add_curve_point(self):
        if not self.points.list:
            self.pushButton_killAllCurvePoints.setEnabled(True)
        new_curve_point = CurvePointSettings()
        new_curve_point.pushButton_kill.clicked.connect(self.remove_curve_point)
        self.verticalLayout_points_settings.addWidget(new_curve_point)
        self.points.list.append(new_curve_point)

    def remove_curve_point(self):
        """un-list all invisible CurvePointSettings."""
        for elt in list(self.points.list):
            if elt.closed:
                del self.points.list[self.points.list.index(elt)]
        if not self.points.list:
            self.pushButton_killAllCurvePoints.setEnabled(False)

    def kill_all_curve_point(self):
        for elt in list(self.points.list):
            elt.close()
            elt.closed = True
        self.remove_curve_point()


if __name__ == "__main__":
    import sys

    try:
        app = QtWidgets.QApplication(sys.argv)

        phiB = {
            "range": {"begin": 25, "step": 5, "end": 45},
            "scalar": 30,
            "focus": "range",
        }
        point = {
            "alpha": {"bound": {"min": 0, "max": 4}, "scalar": 2, "focus": "bound"},
            "beta": {"bound": {"min": -1, "max": 1}, "scalar": 0, "focus": "scalar"},
            "sketch": True,
            "color": (0, 1, 0, 1),
            "size": 5,
            "style": "square",
            "label": "poulpe",
        }
        params = {
            "fluids": "False",
            "phiB": phiB,
            "label": "poulpe",
            "context": "Extension",
            "points": [point, point],
        }

        from eccw_gui.shared.file_management import EccwFile

        eccwf = EccwFile(filename="../../../tests/data/test.eccw")
        params = eccwf.values["plot"]["curves"][0]
        graph_print(params)

        myapp = CurveController(**params)

        sys.exit(app.exec_())
    finally:
        print("params =")
        graph_print(myapp.get_params(), indent=2)
        print("select =")
        graph_print(myapp.get_select(), indent=2)



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../uis/checkBox.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(94, 28)
        self.horizontalLayout = QtWidgets.QHBoxLayout(Form)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setSpacing(6)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.checkBox = QtWidgets.QCheckBox(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBox.sizePolicy().hasHeightForWidth())
        self.checkBox.setSizePolicy(sizePolicy)
        self.checkBox.setMinimumSize(QtCore.QSize(0, 28))
        self.checkBox.setMaximumSize(QtCore.QSize(16777215, 28))
        self.checkBox.setBaseSize(QtCore.QSize(0, 28))
        self.checkBox.setAutoExclusive(False)
        self.checkBox.setObjectName("checkBox")
        self.horizontalLayout.addWidget(self.checkBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.checkBox.setToolTip(_translate("Form", "Activate ruin mecanism drawing"))
        self.checkBox.setText(_translate("Form", "&label"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../uis/title_settings.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(712, 32)
        self.horizontalLayout = QtWidgets.QHBoxLayout(Form)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem = QtWidgets.QSpacerItem(28, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.label = QtWidgets.QLabel(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy)
        self.label.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.horizontalLayout.addWidget(self.label)
        self.lineEdit = QtWidgets.QLineEdit(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEdit.sizePolicy().hasHeightForWidth())
        self.lineEdit.setSizePolicy(sizePolicy)
        self.lineEdit.setMinimumSize(QtCore.QSize(600, 0))
        self.lineEdit.setAlignment(QtCore.Qt.AlignCenter)
        self.lineEdit.setObjectName("lineEdit")
        self.horizontalLayout.addWidget(self.lineEdit)
        spacerItem1 = QtWidgets.QSpacerItem(29, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.label.setToolTip(_translate("Form", "plot title (Alt+T)"))
        self.label.setText(_translate("Form", "<u>T</u>itle"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../uis/point_settings.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(465, 28)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        Form.setMinimumSize(QtCore.QSize(0, 0))
        self.horizontalLayout = QtWidgets.QHBoxLayout(Form)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label_beta = QtWidgets.QLabel(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_beta.sizePolicy().hasHeightForWidth())
        self.label_beta.setSizePolicy(sizePolicy)
        self.label_beta.setMaximumSize(QtCore.QSize(12, 24))
        self.label_beta.setText("")
        self.label_beta.setPixmap(QtGui.QPixmap(":/params/params_beta.png"))
        self.label_beta.setScaledContents(True)
        self.label_beta.setObjectName("label_beta")
        self.horizontalLayout.addWidget(self.label_beta)
        self.horizontalLayout_beta = QtWidgets.QHBoxLayout()
        self.horizontalLayout_beta.setObjectName("horizontalLayout_beta")
        self.horizontalLayout.addLayout(self.horizontalLayout_beta)
        self.label_alpha = QtWidgets.QLabel(Form)
        self.label_alpha.setMaximumSize(QtCore.QSize(12, 24))
        self.label_alpha.setText("")
        self.label_alpha.setPixmap(QtGui.QPixmap(":/params/params_alpha.png"))
        self.label_alpha.setScaledContents(True)
        self.label_alpha.setObjectName("label_alpha")
        self.horizontalLayout.addWidget(self.label_alpha)
        self.horizontalLayout_alpha = QtWidgets.QHBoxLayout()
        self.horizontalLayout_alpha.setObjectName("horizontalLayout_alpha")
        self.horizontalLayout.addLayout(self.horizontalLayout_alpha)
        self.horizontalLayout_settings = QtWidgets.QHBoxLayout()
        self.horizontalLayout_settings.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.horizontalLayout_settings.setObjectName("horizontalLayout_settings")
        self.horizontalLayout.addLayout(self.horizontalLayout_settings)
        spacerItem = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.pushButton_kill = QtWidgets.QPushButton(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_kill.sizePolicy().hasHeightForWidth())
        self.pushButton_kill.setSizePolicy(sizePolicy)
        self.pushButton_kill.setMinimumSize(QtCore.QSize(28, 28))
        self.pushButton_kill.setMaximumSize(QtCore.QSize(28, 28))
        self.pushButton_kill.setBaseSize(QtCore.QSize(28, 28))
        self.pushButton_kill.setText("")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/buttons/button_close.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_kill.setIcon(icon)
        self.pushButton_kill.setObjectName("pushButton_kill")
        self.horizontalLayout.addWidget(self.pushButton_kill)

        self.retranslateUi(Form)
        self.pushButton_kill.clicked.connect(Form.close)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.label_beta.setToolTip(_translate("Form", "Basal slope [deg]"))
        self.label_alpha.setToolTip(_translate("Form", "Surface slope [deg]"))
        self.pushButton_kill.setToolTip(_translate("Form", "Delete this point"))

import eccw_gui.images.ressources_rc

if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../uis/groupBox_context.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(191, 105)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.checkBox_compression = QtWidgets.QCheckBox(self.groupBox)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.checkBox_compression.setFont(font)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/buttons/button_compression.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.checkBox_compression.setIcon(icon)
        self.checkBox_compression.setChecked(True)
        self.checkBox_compression.setAutoExclusive(True)
        self.checkBox_compression.setObjectName("checkBox_compression")
        self.verticalLayout_2.addWidget(self.checkBox_compression)
        self.checkBox_extension = QtWidgets.QCheckBox(self.groupBox)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.checkBox_extension.setFont(font)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/buttons/button_extension.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.checkBox_extension.setIcon(icon1)
        self.checkBox_extension.setAutoExclusive(True)
        self.checkBox_extension.setObjectName("checkBox_extension")
        self.verticalLayout_2.addWidget(self.checkBox_extension)
        self.verticalLayout.addWidget(self.groupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.groupBox.setTitle(_translate("Form", "Tectonic context"))
        self.checkBox_compression.setToolTip(_translate("Form", "Activate compressive tectonic context (Alt+C)"))
        self.checkBox_compression.setText(_translate("Form", " &Compression"))
        self.checkBox_extension.setToolTip(_translate("Form", "Activate extensive tectonic context (Alt+E)"))
        self.checkBox_extension.setText(_translate("Form", " &Extension"))

import eccw_gui.images.ressources_rc

if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from PyQt5 import QtWidgets

from eccw_gui.shared.viewers.checkBox import Ui_Form


class CheckBox(QtWidgets.QWidget, Ui_Form):
    """Radio button widget.

    Arguments:
    Awaits a single boolean that will init the radio button state.

    Keyword arguments:
    label -- string to be displayed near by the radio button.

    This is a Qt derived object.
    """

    def __init__(self, *args, **kwargs):
        super(CheckBox, self).__init__()
        self.setupUi(self)
        # Fill values with args
        if args:
            self.set_params(*args)
        if kwargs:
            self._set_label(**kwargs)
        self.show()

    def _set_label(self, **kwargs):
        label = kwargs.get("label", False)
        if label:
            self.checkBox.setText(label)

    def get_params(self):
        return self.checkBox.isChecked()

    def set_params(self, value):
        if isinstance(value, str):
            value = eval(value)
        self.checkBox.setChecked(value)

    def get_select(self):
        return self.get_params()


if __name__ == "__main__":
    import sys

    try:
        app = QtWidgets.QApplication(sys.argv)
        myapp = CheckBoxContext("Extension")
        sys.exit(app.exec_())
    finally:
        print("params =", myapp.get_params())
        print("select =", myapp.get_select())



#!/usr/bin/env python3
# -*- coding: utf-8 -*-


from PyQt5 import QtWidgets

from eccw_gui.plot_app.viewers.dialog_errors import Ui_Dialog_Errors


class Errors(QtWidgets.QWidget, Ui_Dialog_Errors):
    """Widget for software informations display."""

    def __init__(self, message="", parent=None):
        super(Errors, self).__init__(parent)
        self.setupUi(self)
        self.add_message(message)
        self.show()

    def add_message(self, text):
        self.textEdit.append(text)


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    myapp = Errors("Des erreurs")
    sys.exit(app.exec_())



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from PyQt5 import QtWidgets
from collections import OrderedDict

from eccw_gui.plot_app.viewers.point_settings import Ui_Form
from eccw_gui.shared.controllers.lineEdit import ScalarLineEdit
from eccw_gui.shared.controllers.lineEdit import StringLineEdit
from eccw_gui.shared.controllers.lineEdit import SwitchScalarBound
from eccw_gui.shared.controllers.spinBox import SpinBox
from eccw_gui.shared.controllers.colorButton import ColorButton
from eccw_gui.shared.controllers.comboBox import ComboBoxPoint
from eccw_gui.shared.controllers.label import Label
from eccw_gui.shared.controllers.checkBox import CheckBox
from eccw_gui.shared.wrappers import WrapperDict
from eccw_gui.shared.tools import graph_print


class PointSettings(QtWidgets.QWidget, Ui_Form, WrapperDict):
    """Abstract class."""

    def __init__(self, **kwargs):
        super(PointSettings, self).__init__()
        self.setupUi(self)
        # Init local attributs.
        self.closed = False
        # Init additional objects
        self.labelSize = Label("size")
        self.size = SpinBox(5)
        self.color = ColorButton()
        self.style = ComboBoxPoint()
        self.labelLabel = Label("label")
        self.label = StringLineEdit()
        # Put them in self
        self.horizontalLayout_settings.addWidget(self.labelSize)
        self.horizontalLayout_settings.addWidget(self.size)
        self.horizontalLayout_settings.addWidget(self.color)
        self.horizontalLayout_settings.addWidget(self.style)
        self.horizontalLayout_settings.addWidget(self.labelLabel)
        self.horizontalLayout_settings.addWidget(self.label)
        # Define events
        self.pushButton_kill.clicked.connect(self._setClosed)
        # Dictionnary
        self.dict = OrderedDict(
            [
                ("size", self.size),
                ("color", self.color),
                ("style", self.style),
                ("label", self.label),
            ]
        )

    def _setClosed(self):
        self.closed = True


class RefPointSettings(PointSettings):
    """Widget for reference points parameters and settings entry.

    Keyword arguments:
    beta  -- awaits a dict of keyword arguments for a ScalarLineEdit element.
    alpha -- awaits a dict of keyword arguments for a ScalarLineEdit element.
    size  -- awaits a dict of keyword arguments for a SpinBox element.
    color -- awaits a dict of keyword arguments for a ColorBox element.
    style -- awaits a dict of keyword arguments for a ComboBoxPoint element.
    label -- awaits a dict of keyword arguments for a StringLineEdit element.

    This is a Qt derived object.
    """

    def __init__(self, **kwargs):
        PointSettings.__init__(self, **kwargs)
        self.beta = ScalarLineEdit()
        self.alpha = ScalarLineEdit()
        self.horizontalLayout_beta.addWidget(self.beta)
        self.horizontalLayout_alpha.addWidget(self.alpha)
        # Dictionnary (WrapperDict)
        self.dict = OrderedDict(
            [("beta", self.beta), ("alpha", self.alpha)], **self.dict
        )
        # Fill values with kwargs
        if kwargs:
            self.set_params(**kwargs)
        self.show()


class CurvePointSettings(PointSettings):
    """Widget for points on curve parameters and settings entry.

    Keyword arguments:
    beta  -- awaits a dict of keyword arguments for a SwitchScalarBound
             element.
    alpha -- awaits a dict of keyword arguments for a SwitchScalarBound
             element.
    size  -- awaits a dict of keyword arguments for a SpinBox element.
    color -- awaits a dict of keyword arguments for a ColorBox element.
    style -- awaits a dict of keyword arguments for a ComboBoxPoint element.
    label -- awaits a dict of keyword arguments for a StringLineEdit element.

    This is a Qt derived object.
    """

    def __init__(self, **kwargs):
        PointSettings.__init__(self, **kwargs)
        self.beta = SwitchScalarBound()
        self.alpha = SwitchScalarBound()
        self.sketch = CheckBox(label="sketch")
        self.horizontalLayout_beta.addWidget(self.beta)
        self.horizontalLayout_alpha.addWidget(self.alpha)
        self.horizontalLayout_settings.addWidget(self.sketch)
        # Set initial state
        self.beta.set_scalar_visible(True)
        self.alpha.set_bound_visible(True)
        # Define pushButton behaviours
        self.beta.pushButton.clicked.connect(
            lambda: self._there_must_be_one(self.beta, self.alpha)
        )
        self.alpha.pushButton.clicked.connect(
            lambda: self._there_must_be_one(self.alpha, self.beta)
        )
        # Dictionnary
        self.dict = OrderedDict(
            [("beta", self.beta), ("alpha", self.alpha)], **self.dict
        )
        self.dict.update([("sketch", self.sketch)])
        # Fill values with kwargs
        if kwargs:
            self.set_params(**kwargs)
        self.show()

    def _there_must_be_one(self, elt, other):
        if elt.pushButton.isChecked():
            elt.set_bound_visible(True)
            other.set_scalar_visible(True)
        else:
            elt.set_scalar_visible(True)
            other.set_bound_visible(True)


if __name__ == "__main__":
    import sys

    try:
        app = QtWidgets.QApplication(sys.argv)

        params = {
            "beta": "0",
            "alpha": "3.12",
            "color": ("0", "1", "0", "1"),
            "size": "5",
            "style": "*",
            "label": "poulpe",
        }
        myapp1 = RefPointSettings(**params)

        params = {
            "alpha": {
                "bound": {"min": "0", "max": "4"},
                "scalar": "2",
                "focus": "bound",
            },
            "beta": {
                "bound": {"min": "-1", "max": "1"},
                "scalar": "0",
                "focus": "scalar",
            },
            "sketch": "True",
            "color": ("0", "1", "0", "1"),
            "size": "5",
            "style": "s",
            "label": "poulpe",
        }
        myapp2 = CurvePointSettings(**params)

        sys.exit(app.exec_())
    finally:
        if myapp1:
            print("RefPointSettings")
            print("params =")
            graph_print(myapp1.get_params(), indent=2)
            print("select =")
            graph_print(myapp1.get_select(), indent=2)
        print()
        if myapp2:
            print("CurvePointSettings")
            print("params =")
            graph_print(myapp2.get_params(), indent=2)
            print("select =")
            graph_print(myapp2.get_select(), indent=2)



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../uis/lineEdit_switch.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(146, 28)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        Form.setMinimumSize(QtCore.QSize(146, 0))
        Form.setMaximumSize(QtCore.QSize(146, 16777215))
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(Form)
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_2.setSpacing(0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_2.addLayout(self.verticalLayout)
        self.pushButton = QtWidgets.QPushButton(Form)
        self.pushButton.setMinimumSize(QtCore.QSize(26, 28))
        self.pushButton.setMaximumSize(QtCore.QSize(26, 28))
        self.pushButton.setBaseSize(QtCore.QSize(26, 28))
        self.pushButton.setText("")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/buttons/button_range_off.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon.addPixmap(QtGui.QPixmap(":/buttons/button_range_on.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.pushButton.setIcon(icon)
        self.pushButton.setIconSize(QtCore.QSize(26, 28))
        self.pushButton.setCheckable(True)
        self.pushButton.setChecked(False)
        self.pushButton.setAutoExclusive(False)
        self.pushButton.setObjectName("pushButton")
        self.horizontalLayout_2.addWidget(self.pushButton)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.pushButton.setToolTip(_translate("Form", "Switch input mode : scalar / interval"))

import eccw_gui.images.ressources_rc

if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




#!/usr/bin/env python3
# -*- coding: utf-8 -*-


from PyQt5 import QtCore, QtGui, QtWidgets

from eccw_gui.plot_app.viewers.title_settings import Ui_Form
from eccw_gui.shared.tools import str_check, graph_print


class TitleEdit(QtWidgets.QWidget, Ui_Form):
    """Title edit widget.

    Arguments:
    Awaits a single argument.
    Any entry will initiate the line edit with a string interpretation
    of the argument.
    This is a Qt derived object.
    """

    def __init__(self, *args):
        super(TitleEdit, self).__init__()
        self.id = "title"
        self.setupUi(self)
        # Fill values with args
        if args:
            self.set_params(*args)
        self.show()

    def get_params(self):
        return self.lineEdit.text()

    def set_params(self, arg):
        self.lineEdit.setText(str_check(arg))

    def get_select(self):
        return self.get_params()

    def clear(self):
        self.lineEdit.clear()


if __name__ == "__main__":
    import sys

    try:
        app = QtWidgets.QApplication(sys.argv)

        myapp = TitleEdit("Random Title")
        sys.exit(app.exec_())
    finally:
        print("params=")
        graph_print(myapp.get_params(), indent=2)
        print("select=")
        graph_print(myapp.get_select(), indent=2)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from PyQt5 import QtWidgets

from eccw_gui.shared.viewers.verticalLayout import Ui_Form as UiV
from eccw_gui.shared.viewers.horizontalLayout import Ui_Form as UiH


class VerticalLayout(QtWidgets.QWidget, UiV):
    """Vertical layout widget.
    This is a Qt derived object.
    """

    def __init__(self, *args):
        super(VerticalLayout, self).__init__()
        self.setupUi(self)
        self.show()


class HorizontalLayout(QtWidgets.QWidget, UiH):
    """Horizontal layout widget.
    This is a Qt derived object.
    """

    def __init__(self, *args):
        super(HorizontalLayout, self).__init__()
        self.setupUi(self)
        self.show()


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    myapp = VerticalLayout()
    sys.exit(app.exec_())



#!/usr/bin/env python3
# -*-coding:utf-8 -*

"""
Various shared tools.
"""


def float_check(value, default=None):
    """value must be a float or default."""
    try:
        return float(value)
    except ValueError:
        return default


def str_check(value, default=''):
    """value must be a string or default."""
    if value is None:
        return default
    else:
        return str(value)


def _is_leaf(elt):
    """Return True if elt if not an iterable."""
    if isinstance(elt, dict):
        return False
    elif isinstance(elt, list):
        return False
    elif isinstance(elt, tuple):
        return False
    else:
        return True


def graph_print(elt, indent=0, level=0):
    """Print 'elt' and all its contained elements (if any) in a pretty way.

**How dictionaries are printed**
::

    { key1     : value1
      key2     : value2
      ...
      last_key : valueN
    }

**How lists are printed**
::

    [ 0   : value1
      1   : value2
     ...
      N-1 : valueN
    ]

**How tuples are printed**
::

    ( 0   : value1
      1   : value2
     ...
      N-1 : valueN
    )

.. note:: If lists or tuples are leafs of the graph (ie they do not contains
          iterable elements) they are printed simply using repr().

"""
    if level == 0:
        print(" "*indent, end="")
    if isinstance(elt, dict):
        print("{ ", end="")
        keysizemax = max([len(key) for key in elt.keys()])
        m = indent + 2
        for i, (key, value) in enumerate(elt.items()):
            n = keysizemax - len(key)
            if i != 0:
                print("\n" + " "*(indent + 2), end="")
            print(str(key) + " "*n + " : ", end="")
            graph_print(value, indent + keysizemax + 5, level+1)
        print("\n" + " "*(m-2) + "}", end="")
    elif isinstance(elt, (list, tuple)):
        if all([_is_leaf(e) for e in elt]):
            print(repr(elt), end="")
        else:
            A = "[" if isinstance(elt, list) else "("
            Z = "]" if isinstance(elt, list) else ")"
            print(A + " ", end="")
            indexsizemax = len(str(len(elt)-1))
            m = indent + 2
            for i, value in enumerate(elt):
                n = indexsizemax - len(str(i))
                if i != 0:
                    print("\n" + " "*(indent + 2), end="")
                print(str(i) + " "*n + " : ", end="")
                graph_print(value, indent + indexsizemax + 5, level+1)
            print("\n" + " "*(m-2) + Z, end="")
    else:
        print(repr(elt), end="")
    if level == 0:
        print()


if __name__ == "__main__":

    from collections import OrderedDict as OD

    test = OD([
        ("value", 1.),
        ("text", "foo"),
        ("bool", True),
        ("dict", OD([
            ("value", 1.),
            ("text", "foo"),
            ("bool", True),
            ("tuple", (1, 2, 3)),
            ("list", ["A", "B", "C"])
            ])),
        ("list", [1., "foo", True, (1, 2, 3), ["A", "B", "C"]]),
        ("tuple", (1., "foo", True, (1, 2, 3), ["A", "B", "C"]))
        ])
    graph_print(test)  # , indent=4)



#!/usr/bin/env python3
# -*-coding:utf-8 -*

"""
Tools and objects dedicated to manage inputs/outputs files.
"""

from collections import OrderedDict
import xmltodict
from xml.parsers.expat import ExpatError
import webbrowser
import sys

from eccw_gui import  __location__
from eccw_gui.shared.tools import graph_print


class EccwFile():
    """Read/Write an eccw session file.

    **Usage**

    >>> f = EccwFile("path/to/file.eccw")
    >>> f.show()
    >>> f.save("path/to/newfile.eccw")
    """
    mime = "eccw"

    def __init__(self, data=None, filename=None):
        self.values = data
        if filename is not None:
            self.load(filename)

    def _check_in(self, elt, key):
        if elt[key] == [None]:
            # No elts must be stored as an empty list entry.
            elt[key] = []

    def _check_out(self, elt, key):
        if elt[key] == []:
            # Empty list has to be enlighted to be stored as xml.
            elt[key] = [None]

    def load(self, filename):
        # Keywords that must be present in the result even if empty.
        fl = ('refpoints', 'points', 'curves')
        xmlfile = open(filename, 'r')
        try:
            tmp = xmltodict.parse(xmlfile.read(), force_list=fl)
        except ExpatError:
            self.values = None
            return
        xmlfile.close()
        try:
            self.values = tmp["session"]
            # Replace wrong formated elements by proper values.
            if self.values["calculator"]['results'] is None:
                self.values["calculator"]['results'] = ''
            self._check_in(self.values["plot"], "refpoints")
            self._check_in(self.values["plot"], "curves")
            for i in range(len(self.values["plot"]["curves"])):
                self._check_in(self.values["plot"]["curves"][i], "points")
        except KeyError:
            self.values = None
            return

    def save(self, filename):
        xmlfile = open(filename, 'w')
        xmlfile.write(self.xml())
        xmlfile.close()

    def show(self):
        graph_print(self.values)

    def xml(self, pretty=True):
        values = OrderedDict(self.values)
        # Replace empty list elements by [None] for xmltodict.
        self._check_out(self.values["plot"], "refpoints")
        self._check_out(self.values["plot"], "curves")
        for i in range(len(self.values["plot"]["curves"])):
            self._check_out(self.values["plot"]["curves"][i], "points")

        return xmltodict.unparse({"session": values}, pretty=pretty)


def open_pdf(file_name):
#    file_name = "".join([p for p in sys.path if p[-4:] == "eccw"]
#                        + [file_name])
    file_name = __location__ + "/" + file_name
    webbrowser.open(file_name, new=0, autoraise=True)

if __name__ == "__main__":

    f = EccwFile()
    f.load("../../tests/test.eccw")
    f.show()



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../uis/groupBox_fluids.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(194, 101)
        self.horizontalLayout = QtWidgets.QHBoxLayout(Form)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.groupBox_fluids = QtWidgets.QGroupBox(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_fluids.sizePolicy().hasHeightForWidth())
        self.groupBox_fluids.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.groupBox_fluids.setFont(font)
        self.groupBox_fluids.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.groupBox_fluids.setCheckable(True)
        self.groupBox_fluids.setChecked(False)
        self.groupBox_fluids.setObjectName("groupBox_fluids")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox_fluids)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label_rhosr = QtWidgets.QLabel(self.groupBox_fluids)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_rhosr.sizePolicy().hasHeightForWidth())
        self.label_rhosr.setSizePolicy(sizePolicy)
        self.label_rhosr.setMaximumSize(QtCore.QSize(24, 24))
        self.label_rhosr.setText("")
        self.label_rhosr.setPixmap(QtGui.QPixmap(":/params/params_rhosr.png"))
        self.label_rhosr.setScaledContents(True)
        self.label_rhosr.setObjectName("label_rhosr")
        self.gridLayout_2.addWidget(self.label_rhosr, 1, 4, 1, 1)
        self.horizontalLayout_rhof = QtWidgets.QHBoxLayout()
        self.horizontalLayout_rhof.setSpacing(0)
        self.horizontalLayout_rhof.setObjectName("horizontalLayout_rhof")
        self.gridLayout_2.addLayout(self.horizontalLayout_rhof, 0, 5, 1, 1)
        self.horizontalLayout_lamdaB = QtWidgets.QHBoxLayout()
        self.horizontalLayout_lamdaB.setSpacing(0)
        self.horizontalLayout_lamdaB.setObjectName("horizontalLayout_lamdaB")
        self.gridLayout_2.addLayout(self.horizontalLayout_lamdaB, 0, 2, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.groupBox_fluids)
        self.label_3.setMaximumSize(QtCore.QSize(6, 24))
        self.label_3.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_3.setObjectName("label_3")
        self.gridLayout_2.addWidget(self.label_3, 0, 0, 1, 1)
        self.horizontalLayout_rhosr = QtWidgets.QHBoxLayout()
        self.horizontalLayout_rhosr.setSpacing(0)
        self.horizontalLayout_rhosr.setObjectName("horizontalLayout_rhosr")
        self.gridLayout_2.addLayout(self.horizontalLayout_rhosr, 1, 5, 1, 1)
        self.label_lamdaD = QtWidgets.QLabel(self.groupBox_fluids)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_lamdaD.sizePolicy().hasHeightForWidth())
        self.label_lamdaD.setSizePolicy(sizePolicy)
        self.label_lamdaD.setMaximumSize(QtCore.QSize(30, 24))
        self.label_lamdaD.setText("")
        self.label_lamdaD.setPixmap(QtGui.QPixmap(":/params/params_lamdaD.png"))
        self.label_lamdaD.setScaledContents(True)
        self.label_lamdaD.setObjectName("label_lamdaD")
        self.gridLayout_2.addWidget(self.label_lamdaD, 1, 1, 1, 1)
        self.label_lamdaB = QtWidgets.QLabel(self.groupBox_fluids)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_lamdaB.sizePolicy().hasHeightForWidth())
        self.label_lamdaB.setSizePolicy(sizePolicy)
        self.label_lamdaB.setMaximumSize(QtCore.QSize(30, 24))
        self.label_lamdaB.setPixmap(QtGui.QPixmap(":/params/params_lamdaB.png"))
        self.label_lamdaB.setScaledContents(True)
        self.label_lamdaB.setObjectName("label_lamdaB")
        self.gridLayout_2.addWidget(self.label_lamdaB, 0, 1, 1, 1)
        self.horizontalLayout_lamdaD = QtWidgets.QHBoxLayout()
        self.horizontalLayout_lamdaD.setSpacing(0)
        self.horizontalLayout_lamdaD.setObjectName("horizontalLayout_lamdaD")
        self.gridLayout_2.addLayout(self.horizontalLayout_lamdaD, 1, 2, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.groupBox_fluids)
        self.label_4.setMaximumSize(QtCore.QSize(6, 24))
        self.label_4.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_4.setObjectName("label_4")
        self.gridLayout_2.addWidget(self.label_4, 1, 0, 1, 1)
        self.label_rhof = QtWidgets.QLabel(self.groupBox_fluids)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_rhof.sizePolicy().hasHeightForWidth())
        self.label_rhof.setSizePolicy(sizePolicy)
        self.label_rhof.setMaximumSize(QtCore.QSize(24, 24))
        self.label_rhof.setText("")
        self.label_rhof.setPixmap(QtGui.QPixmap(":/params/params_rhof.png"))
        self.label_rhof.setScaledContents(True)
        self.label_rhof.setObjectName("label_rhof")
        self.gridLayout_2.addWidget(self.label_rhof, 0, 4, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.groupBox_fluids)
        self.label_5.setMaximumSize(QtCore.QSize(12, 24))
        self.label_5.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_5.setObjectName("label_5")
        self.gridLayout_2.addWidget(self.label_5, 0, 3, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.groupBox_fluids)
        self.label_6.setMaximumSize(QtCore.QSize(12, 24))
        self.label_6.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_6.setObjectName("label_6")
        self.gridLayout_2.addWidget(self.label_6, 1, 3, 1, 1)
        self.horizontalLayout.addWidget(self.groupBox_fluids)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.groupBox_fluids.setToolTip(_translate("Form", "Check to activate fluids pore pressure parameters"))
        self.groupBox_fluids.setTitle(_translate("Form", "&Fluids pore pressure"))
        self.label_rhosr.setToolTip(_translate("Form", "Volumetric mass density of saturated rock"))
        self.label_3.setText(_translate("Form", "<sup>5</sup>"))
        self.label_lamdaD.setToolTip(_translate("Form", "Basal fluids overpressure ratio"))
        self.label_lamdaB.setToolTip(_translate("Form", "Bulk fluids overpressure ratio"))
        self.label_4.setText(_translate("Form", "<sup>6</sup>"))
        self.label_rhof.setToolTip(_translate("Form", "Volumetric mass density of fluids"))
        self.label_5.setText(_translate("Form", "<sup>7</sup>"))
        self.label_6.setText(_translate("Form", "<sup>8</sup>"))

import eccw_gui.images.ressources_rc

if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




import sys
import os
import datetime

global app_name
app_name = "eccw"
global app_description
app_description = """
Exact Critical Coulomb Wedge - Graphical User Interface. 
Tools to compute and display the exact solution of any parameter.
"""
global datadir
datadir = os.path.join(get_special_folder_path("CSIDL_APPDATA"), app_name)

def main(argv):
    if "-install" in argv:
        desktop = get_special_folder_path("CSIDL_DESKTOPDIRECTORY")
        print("Desktop path: %s" % repr(desktop))
        if not os.path.exists(datadir):
            os.makedirs(datadir)
            dir_created(datadir)
            print("Created data directory: %s" % repr(datadir))
        else:
            print("Data directory already existed at %s" % repr(datadir))

        shortcut = os.path.join(desktop, app_name + ".lnk")
        if os.path.exists(shortcut):
            print("Remove existing shortcut at %s" % repr(shortcut))
            os.unlink(shortcut)

        print("Creating shortcut at %s...\n" % shortcut)
        create_shortcut(
            #r'C:\Python36\python.exe',
            os.path.join(sys.prefix, "pythonw.exe"),
            app_description,
            shortcut, 
            "",
            datadir)
        file_created(shortcut)
        print("Successfull!")
    elif "-remove" in sys.argv:
        print("Removing...")
        pass


if __name__ == "__main__":
    logfile = f"C:\{app_name}_install.log" # Fallback location
    if os.path.exists(datadir):
        logfile = os.path.join(datadir, "install.log")
    elif os.environ.get("TEMP") and os.path.exists(os.environ.get("TEMP"),""):
        logfile = os.path.join(os.environ.get("TEMP"), f"{app_name}_install.log")

    with open(logfile, 'a+') as f:
        f.write("Opened\r\n")
        f.write("Ran %s %s at %s" % (sys.executable, " ".join(sys.argv), datetime.datetime.now().isoformat()))
        sys.stdout = f
        sys.stderr = f
        try:
            main(sys.argv)
        except Exception as e:
            raise
        f.close()

    sys.exit(0)



#!/usr/bin/env python3
# -*-coding:utf-8 -*


"""
ECCW
allows to compute the exact solution of critical Coulomb wedge, draw it,
sketch it, with love. Are available compressive or extensive geological
context, with or without fluid pore pressure.

Created on Nov 6 10:58:41 2017
@author: bcl mary
"""

import sys
from PyQt5 import QtWidgets
import argparse


from eccw_gui.main_app.controllers.main import MainController
from eccw_gui.shared.file_management import EccwFile
from eccw_gui.shared.file_management import open_pdf
from eccw_gui import __version__, __authors__


def options_parser():
    """Parse options given with the execute command line."""

    # Create a parser object.
    parser = argparse.ArgumentParser(
        formatter_class=argparse.RawTextHelpFormatter,
        add_help=False,
        description="""
ECCW - Exact Critical Coulomb Wedge, Version {0}

Copyright 2016-2018 {1}
This program comes with ABSOLUTELY NO WARRANTY.
This is free software, and you are welcome to redistribute it
under certain conditions.

ECCW is a Qt interface using python package 'eccw' to
compute and draw the exact solution of critical Coulomb wedge
(as Dahlen 1984 and Yuan et al. 2015)
""".format(__version__, ", ".join(__authors__)),
        )

    # Optional arguments.
    optarg = parser.add_argument_group(
        title="-"*30+"\nOPTIONAL ARGUMENT",
        description=""
        )

    optarg.add_argument(
        '-h', '--help',
        action='help',
        help="show this help message and exit\n\n"
        )

    optarg.add_argument(
        '-V', '--version',
        action='version',
        version=__version__,
        help="show program's version number and exit\n\n"
        )

    optarg.add_argument(
        '-d', '--doc',
        dest="doc",
        action='store_true',
        help="show complete documentation and exit\n\n"
        )

    optarg.add_argument('-f', '--file',
                        dest="file",
                        metavar=("FILE"),
                        type=(str),
                        help="re-start session saved in FILE (*.eccw)\n\n")

    # Parse the command line from the shell.
    inputoptions = parser.parse_args()

    # Treat parsed commands.
    if inputoptions.doc is True:
        open_pdf("/eccw_gui/documentation/ECCW.pdf")
        exit()


    return inputoptions.file


def launch():
    out = options_parser()
    app = QtWidgets.QApplication(sys.argv)
    params = dict()
    if out:
        eccwf = EccwFile(filename=out)
        params = eccwf.values
    myapp = MainController(**params)
    sys.exit(app.exec_())


if __name__ == "__main__":
    launch()
